/**
 * 业务 模块
 */
import API from '../api'
import axios from '../../utils/request' // 导入http中创建的axios实例
import qs from 'qs' // 根据需求是否导入qs模块
/**
 * 商标订单 普通注册
 * @param {Function} getTmOrder   商标订单列表
 * @param {Function} putTmOrderDetail  修改商标订单
 * @param {Function} getTmOrderDetail   获取订单详情
 * @param {Function} deleteTmOrder   删除订单
 */
export function getTmOrderTemp(params) {
  return axios.get('/admin/tm_reg_temp?' + qs.stringify(params))
}
export function deleteTmOrderTemp(id) {
  return axios.delete('/admin/tm_reg_temp/' + id)
}
export function getTmOrderTempDetail(id) {
  return axios.get('/admin/tm_reg_temp/' + id)
}
export function getTmOrder(params) {
  return axios.get(`${API.adminTmOrder}`, { params })
}

export function getTmOrderDetail(id) {
  return axios.get(`${API.adminTmOrder}` + '/' + id)
}
export function putTmOrderDetail(id, params, config) {
  return axios.put(`${API.adminTmOrder}` + '/' + id, params, config || {})
}
export function deleteTmOrder(id) {
  return axios.delete(`${API.adminTmOrder}` + '/' + id)
}

/**
 * 商标申请人
 * TODO 只有tm可以编辑商标申请人
 * 没有进行商标注册才可以删除
 * @param {Function} identifyImage     卡证文字识别
 * @param {Function} getApplicantList  获取详情
 * @param {Function} getApplicantDetail  获取详情
 * @param {Function} putApplicant     编辑
 * @param {Function} deleteApplicant   删除
 */
export function identifyImage(params) {
  return axios.post(`${API.characterRecognition}`, qs.stringify(params))
}
export function getApplicantList(params) {
  return axios.get(`${API.adminTmApplicant}`, { params })
}
export function getApplicantDetail(id) {
  return axios.get(`${API.adminTmApplicant}` + '/' + id)
}
export function putApplicant(id, params) {
  return axios.put(`${API.adminTmApplicant}` + '/' + id, qs.stringify(params))
}
export function deleteApplicant(id) {
  return axios.delete(`${API.adminTmApplicant}` + '/' + id)
}

/**
 * 保姆注册
 */
export function postNurseSubmit(id, params, config) {
  return axios.post(`${API.adminNurseReg}` + '/' + id, params, config || {})
}
export function getNurseList(params) {
  return axios.get(`${API.adminNurseReg}`, { params })
}
export function getNurseTempList(params) {
  return axios.get('/admin/tm_agent_reg_temp', { params })
}
export function deleteNurseOrderTemp(id) {
  return axios.delete('/admin/tm_agent_reg_temp' + '/' + id)
}
export function deleteNurseOrder(id) {
  return axios.delete(`${API.adminNurseReg}` + '/' + id)
}

export function getNurseDetail(id) {
  return axios.get(`${API.adminNurseReg}` + '/' + id)
}
export function putNurseOrder(id, params) {
  return axios.put(`${API.adminTmApplicant}` + '/' + id, qs.stringify(params))
}
export function createImage(params, config) {
  return axios.get(
    'admin/tm_create_image',
    { params },
    config || {}
  )
}
export function delegationFile(params, config) {
  return axios.get(
    'admin/tm_delegation_file',
    { params },
    config || {}
  )
}

/**
 * 商标服务 adminTmService
 * @param {Function} getAdminTmServiceList     获取列表
 * @param {Function} getAdminTmServiceDetail   获取详情
 * @param {Function} putAdminTmService         修改
 * @param {Function} deleteAdminTmService      删除
 */
export function getAdminTmServiceList(params) {
  return axios.get(`${API.adminTmService}`, { params })
}
export function getAdminTmServiceDetail(id) {
  return axios.get(`${API.adminTmService}` + '/' + id)
}
export function putAdminTmService(id, params) {
  return axios.put(`${API.adminTmService}` + '/' + id, params)
}
export function deleteAdminTmService(id) {
  return axios.delete(`${API.adminTmService}` + '/' + id)
}

/**
 * 商标监控 adminTmMonitor
 */
export function getAdminTmMonitorList(params) {
  return axios.get(`${API.adminTmMonitor}`, { params })
}
export function deleteAdminTmMonitor(id) {
  return axios.delete(`${API.adminTmMonitor}` + '/' + id)
}
/**
 * 商标发文列表 adminTmFile
 * 索取发文 adminTmFileFetch
 *
 */
export function getAdminTmFileList(params) {
  return axios.get(`${API.adminTmFile}`, { params })
}
export function deleteAdminTmFile(id) {
  return axios.delete(`${API.adminTmFile}` + '/' + id)
}
export function getAdminTmFileFetchList(params) {
  return axios.get(`${API.adminTmFileFetch}`, { params })
}
export function postAdminTmFileFetch(params) {
  return axios.post(`${API.adminTmFileFetch}`, qs.stringify(params))
}
export function deleteAdminTmFileFetch(id) {
  return axios.delete(`${API.adminTmFileFetch}` + '/' + id)
}
export function getAdminTmFileFetchDetail(id) {
  return axios.get(`${API.adminTmFileFetch}` + '/' + id)
}
export function putAdminTmFileFetch(id, params) {
  return axios.put(`${API.adminTmFileFetch}` + '/' + id, params)
}
/**
 * 专利和版权 AdminTmPatent AdminTmCopyright
 *
 * @param {Function} getAdminTmPatentList          获取专利列表
 * @param {Function} getAdminTmFileCopyrightList   获取版权列表
 * @param {Function} putAdminTmPatent              编辑专利
 * @param {Function} putAdminTmFileCopyright       编辑版权
 * @param {Function} deleteAdminTmPatent           删除专利
 * @param {Function} deleteAdminTmCopyright        删除版权
 */
export function getAdminTmPatentList(params) {
  return axios.get(`${API.adminTmPatent}`, params)
}
export function getAdminTmPatentDetail(id) {
  return axios.get(`${API.adminTmPatent}/${id}`)
}
export function getAdminTmCopyrightList(params) {
  return axios.get(`${API.adminTmCopyright}`, params)
}
export function getAdminTmCopyrightDetail(id) {
  return axios.get(`${API.adminTmCopyright}/${id}`)
}
export function putAdminTmPatent(id, params) {
  return axios.put(`${API.adminTmPatent}` + '/' + id, params)
}
export function putAdminTmCopyright(id, params) {
  return axios.put(`${API.adminTmCopyright}` + '/' + id, params)
}
export function deleteAdminTmPatent(id) {
  return axios.delete(`${API.adminTmPatent}` + '/' + id)
}
export function deleteAdminTmCopyright(id) {
  return axios.delete(`${API.adminTmCopyright}` + '/' + id)
}
/**
 * 国际商标 AdminTmInternational
 *
 * @param {Function} getAdminTmInternational        列表
 * @param {Function} putAdminTmInternational        修改
 * @param {Function} deleteAdminTmInternational     删除
 * @param {Function} getAdminTmInternationalDetail  详情
 */
export function getAdminTmInternational(params) {
  return axios.get(`${API.adminTmInternational}`, { params })
}
export function putAdminTmInternational(params) {
  return axios.put(`${API.adminTmInternational}`, params)
}
export function deleteAdminTmInternational(id) {
  return axios.delete(`${API.adminTmInternational}` + '/' + id)
}
export function getAdminTmInternationalDetail(id) {
  return axios.get(`${API.adminTmInternational}` + '/' + id)
}
/**
 * 商标云交易库订单列表 AdminTmTransaction
 *
 * @param {Function} getAdminTransactionCloud        列表
 * @param {Function} deleteAdminTransactionCloud     删除
 * @param {Function} getAdminTransactionCloudDetail  详情
 * @param {Function} putAdminTransactionCloud      支付服务费和尾款
 *
 */
export function getAdminTransactionCloud(params) {
  return axios.get(`${API.adminTransactionCloud}`, { params })
}
export function deleteAdminTransactionCloud(id) {
  return axios.delete(`${API.adminTransactionCloud}` + '/' + id)
}
export function getAdminTransactionCloudDetail(id) {
  return axios.get(`${API.adminTransactionCloud}` + '/' + id)
}
export function putAdminTransactionCloud(id, params) {
  return axios.put(`${API.adminTransactionCloud}` + '/' + id, params)
}
/**
 * 商标发布 AdminTransactionPlatform
 *
 * @param {Function} getAdminTransactionPlatform        列表
 * @param {Function} deleteAdminTransactionPlatform    删除
 * @param {Function} getAdminTransactionPlatformDetail  详情
 * @param {Function} putAdminTransactionPlatform      修改
 *
 */
export function getAdminTransactionPlatform(params) {
  return axios.get(`${API.adminTransactionPlatform}`, params)
}
export function deleteAdminTransactionPlatform(id) {
  return axios.delete(`${API.adminTransactionPlatform}` + '/' + id)
}
export function getAdminTransactionPlatformDetail(id) {
  return axios.get(`${API.adminTransactionPlatform}` + '/' + id)
}
export function putAdminTransactionPlatform(id, params) {
  return axios.put(`${API.adminTransactionPlatform}` + '/' + id, params)
}
/**
 * 商标持有人 AdminTransactionHolder
 *
 * @param {Function} getAdminTransactionHolder        列表
 * @param {Function} deleteAdminTransactionHolder    删除
 * @param {Function} getAdminTransactionHolderDetail  详情
 * @param {Function} putAdminTransactionHolder      修改
 *
 */
export function getAdminTransactionHolder(params) {
  return axios.get(`${API.adminTransactionHolder}`, { params })
}

export function deleteAdminTransactionHolder(id) {
  return axios.delete(`${API.adminTransactionHolder}` + '/' + id)
}
export function getAdminTransactionHolderDetail(id) {
  return axios.get(`${API.adminTransactionHolder}` + '/' + id)
}
export function putAdminTransactionHolder(id, params) {
  return axios.put(`${API.adminTransactionHolder}` + '/' + id, params)
}

export function getGongzheng(params) {
  return axios.get('/admin/tm_notarization?' + qs.stringify(params))
}
export function getGongzhengDetail(id) {
  return axios.get('/admin/tm_notarization/' + id)
}
export function getGongzhengTemp(params) {
  return axios.get('/admin/tm_notarization_temp?' + qs.stringify(params))
}
export function getGongzhengTempDetail(id) {
  return axios.get('/admin/tm_notarization_temp/' + id)
}
export function deleteGongzhengTemp(id) {
  return axios.delete('/admin/tm_notarization_temp/' + id)
}

/**
 * 官微建站 adminWebsites
 *
 * @param {Function} getAdminWebsites         网站列表
 * @param {Function} deleteAdminWebsites      删除
 * @param {Function} putAdminWebsitesClose    关闭
 * @param {Function} putAdminWebsitesOpen     开启
 * @param {Function} putAdminWebsitesPush     过户
 * @param {Function} getAdminWebsitesDomains  网站域名列表
 * @param {Function} getAdminWebsitesPushes   网站过户记录列表
 * @param {Function} getAdminGWIcpCodes       备案码列表
 * @param {Function} getAdminGWDashboard      控制面包登录地址
 * @param {Function} getAdminGWMina           官微小程序
 *
 *
 */
export function getAdminWebsites(params) {
  return axios.get(`${API.adminWebsites}`, { params })
}
export function deleteAdminWebsites(id) {
  return axios.delete(`${API.adminWebsites}` + '/' + id)
}
export function putAdminWebsitesClose(id) {
  return axios.put(`${API.adminWebsitesClose}` + '/' + id)
}
export function putAdminWebsitesOpen(id) {
  return axios.put(`${API.adminWebsitesOpen}` + '/' + id)
}
export function putAdminWebsitesPush(id, params) {
  return axios.put(`${API.adminWebsitesPush}` + '/' + id, params)
}

export function getAdminWebsitesDomains(params) {
  return axios.get(`${API.adminWebsitesDomains}`, params)
}
export function getAdminWebsitesPushes(params) {
  return axios.get(`${API.adminWebsitesPushes}`, params)
}
export function getAdminGWIcpCodes(params) {
  return axios.get(`${API.adminGWIcpCodes}`, { params })
}
export function getAdminGWDashboard(id) {
  return axios.get(`${API.adminWebsitesDashboard}` + '/' + id)
}
export function getAdminGWMina() {
  return axios.get(`${API.adminGWMina}`)
}
/**
 * 云服务器
 */

export function getAdminUserServer() {
  return axios.get(`${API.adminServer}`)
}

/**
 * SSL
 */

export function getAdminSsl(params) {
  return axios.get(`${API.adminSsl}`, params)
}
export function getAdminSslDetail(id) {
  return axios.get(`${API.adminSsl}` + '/' + id)
}

export function deleteCompanyService(id) {
  return axios.delete('/admin/custom_service' + '/' + id)
}
export function deleteCompanyServiceTemp(id) {
  return axios.delete('/admin/custom_service_temp' + '/' + id)
}
