/**
 * @Name          : ePower
 * @Author        : feng
 * @Version       : 1.0.0
 * @Update        : 2019-12-09
 * @direction     : 公共接口
 */

import API from '../api' // 导入接口域名列表
import axios from '../../utils/request' // 导入http中创建的axios实例
import qs from 'qs'

/**
 * 路由
 * @param {Function} getMenu 获取该角色对应的菜单
 */
export function getMenu() {
  return axios.get(`${API.userMenu}`)
}

/**
 * token的处理
 */
export function getServerToken(params) {
  return axios.post(`${API.token}`, qs.stringify(params), { processMessage: '正在登录...' })
}
export function getUserInfo() {
  return axios.get(`${API.userInfo}`)
}

export function removeServerToken() {
  return axios.delete(`${API.tokenInfo}`, { processMessage: '正在退出...' })
}
/**
 * 上传图片先删除原有图片
 * @param {Function} deleteFile 删除对应图片
 */
export function deleteFile(id) {
  return axios.delete(`${API.fileUpload}` + '/' + id)
}

export function loadJsonData($url) {
  return axios.get($url, { baseURL: '/', responseType: 'json' })
}
export function address() {
  return axios.get(API.resources.address, { baseURL: '/', responseType: 'json' })
}
const require_cache = {}

function parseResponse(data, $config) {
  const module = { exports: {}};
  (new Function('module', 'exports', data))(module, module.exports)
  if ($config && $config.flat === true) {
    const idName = $config['id'] || 'id'
    const parentIdName = $config['parent_id'] || 'parent_id'
    const data = module.exports
    if (!(data instanceof Array)) return module.exports

    const result = { maps: {}, datas: {}}; let item = null; let parent_id

    const maps = result.maps
    const datas = result.datas
    for (let i = 0; i < data.length; i++) {
      item = data[i]
      parent_id = item[parentIdName]
      datas[item[idName]] = item
      if (!maps.hasOwnProperty(parent_id)) {
        maps[parent_id] = []
      }
      maps[parent_id].push(item)
    }
    return result
  }
  return module.exports
}
export function require($url, $config) {
  if (require_cache.hasOwnProperty($url)) {
    return new Promise((resolve, reject) => {
      resolve(parseResponse(require_cache[$url], $config))
    })
  }
  return axios.get($url, {
    baseURL: '/',
    responseType: 'text',
    validateStatus: statusCode => true,
    ignoreInterceptors: true
  }).then(function(response) {
    if (response.status >= 400 || !response.data) return null
    require_cache[$url] = response.data
    return parseResponse(response.data, $config)
  })
}

export function getVariables(scope) {
  return axios.get('/platform_variables', { baseURL: '/', params: { vars: scope || 'manage,version' }})
}
