/**
 * @Name          : ePower
 * @Author        : feng
 * @Version       : 1.0.0
 * @Update        : 2019-12-09
 * @direction     : 产品管理
 */
import API from '../api' // 导入接口域名列表
import axios from '@/utils/request' // 导入http中创建的axios实例
import qs from 'qs' // 根据需求是否导入qs模块

/**
 * 产品管理
 * @param {Function} getProducts 获取对应的产品列表
 * @param {Function} postAdminSyncProducts 同步产品
 *
 */
export function getProducts(cls) {
  return axios.get(`${API.adminProducts}` + '?product_type=' + cls)
}

export function postAdminSyncProducts(params) {
  return axios.post(`${API.adminSyncProducts}`, qs.stringify(params))
}

/**
 * 价格设置
 * @param {Function} setPrices 设置价格
 * @param {Function} getPrices 获取价格
 * TODO getPrices 去除include=prices
 * @param {Function} getPriceDetail 获取价格详情
 * @param {Function} postAdminSyncPrices 同步价格
 * @param {Function} postAdminPricesInit 价格初始化
 *
 */
export function addPrices(params) {
  return axios.post(`${API.adminPrices}`, params)
}
export function updatePrices(id, params) {
  return axios.put(`${API.adminPrices}` + '/' + id, params)
}
export function getPrices(params) {
  return axios.get(`${API.adminPrices}` + '?product_type=' + params)
}
export function setPriceBatch(params) {
  return axios.post(`${API.adminPrices}` + '/batch', params)
}
export function getPriceDetail(id) {
  return axios.get(`${API.adminPrices}` + '/' + id)
}
export function postAdminSyncPrices(params) {
  return axios.post(`${API.adminSyncPrices}`, qs.stringify(params))
}
export function postAdminPricesInit(params) {
  return axios.post(`${API.adminPriceInit}`, qs.stringify(params))
}

/**
 * 企业服务
 * @param {Function} addBusinessTax     新增
 * @param {Function} getBusinessTax     获取列表
 * @param {Function} putBusinessTax     修改
 * @param {Function} sortBusinessTax    排序
 * @param {Function} deleteBusinessTax  删除
 *
 */

export function addBusinessTax(params) {
  return axios.post(`${API.adminBusinessTax}`, params)
}
export function getBusinessTax(params) {
  return axios.get(`${API.adminBusinessTax}`, params)
}
export function putBusinessTax(id, params) {
  return axios.put(`${API.adminBusinessTax}` + '/' + id, qs.stringify(params))
}
export function sortBusinessTax(params) {
  return axios.post(`${API.adminBusinessTax}` + '/order', qs.stringify(params))
}
export function deleteBusinessTax(id) {
  return axios.delete(`${API.adminBusinessTax}` + '/' + id)
}

/**
 * 企业服务服务类型
 * @param {Function} addBusinessTaxType     新增
 * @param {Function} getBusinessTaxType     获取列表
 * @param {Function} putBusinessTaxType     修改
 * @param {Function} sortBusinessTaxType    排序
 * @param {Function} deleteBusinessTaxType  删除
 *
 */
export function addBusinessTaxType(params) {
  return axios.post(`${API.adminBusinessTaxType}`, params)
}
export function getBusinessTaxType() {
  return axios.get(`${API.adminBusinessTaxType}`)
}
export function putBusinessTaxType(id, params) {
  return axios.put(
    `${API.adminBusinessTaxType}` + '/' + id,
    qs.stringify(params)
  )
}
export function sortBusinessTaxType(params) {
  return axios.post(
    `${API.adminBusinessTaxType}` + '/order',
    qs.stringify(params)
  )
}
export function deleteBusinessTaxType(id) {
  return axios.delete(`${API.adminBusinessTaxType}` + '/' + id)
}
/**
 * 企业服务 产品属性
 * @param {*} params
 */

export function addBusinessTaxAttr(params) {
  return axios.post(`${API.adminBusinessTaxAttr}`, params)
}
export function getBusinessTaxAttr(id) {
  return axios.get(`${API.adminBusinessTaxAttr}`)
}
export function putBusinessTaxAttr(id, params) {
  return axios.put(
    `${API.adminBusinessTaxAttr}` + '/' + id,
    qs.stringify(params)
  )
}
export function deleteBusinessTaxAttr(id) {
  return axios.delete(`${API.adminBusinessTaxAttr}` + '/' + id)
}
/**
 * 商标知产
 * @param {Function} addTmProducts     新增
 * @param {Function} getTmProducts     获取列表
 * @param {Function} putTmProducts     修改
 * @param {Function} sortTmProducts    排序
 * @param {Function} deleteTmProducts  删除
 * @param {Function} getTmClasses      获取商标分类
 * @param {Function} postAdminTmSaleSync      同步云平台商标数据
 * @param {Function} deleteAdminTmSale        删除云平台商标数据
 *
 *
 */

export function getSmsProducts(params) {
  return axios.get(`${API.adminSmsProducts}`, params)
}
export function getTmProducts(params) {
  return axios.get(`${API.adminTmProducts}`, params)
}
export function putTmProducts(id, params) {
  return axios.put(`${API.adminTmProducts}` + '/' + id, qs.stringify(params))
}
export function putSmsProducts(id, params) {
  return axios.put(`${API.adminSmsProducts}` + '/' + id, qs.stringify(params))
}

export function deleteTmProducts(id) {
  return axios.delete(`${API.adminTmProducts}` + '/' + id)
}

export function getTmClasses(params) {
  return axios.get(`${API.adminTmClasses}` + '?parent_class=' + params)
}
export function syncTmClasses() {
  return axios.get(`${API.adminTmClasses}/sync`)
}

export function getAdminTmSaleList(params) {
  return axios.get(`${API.adminTmSale}`, { params })
}

export function getAdminTmSaleDetail(id) {
  return axios.get('admin/tm_trade_lib/' + id)
}

export function putAdminTmSale(id, params) {
  return axios.put('admin/tm_trade_lib/' + id, qs.stringify(params))
}
export function postAdminTmSaleCache() {
  return axios.post('admin/tm_trade_lib/cache')
}
export function postAdminTmSaleSync(params, config) {
  return axios.post(`${API.adminTmSale}` + '/sync', params, config)
}

export function deleteAdminTmSale(id) {
  return axios.delete(`${API.adminTmSaleDelete}` + '/' + id)
}

export function getAdminTmSaleLocalList(params) {
  return axios.get('admin/tm_trade_local_lib', { params })
}

export function getAdminTmSaleLocalDetail(id) {
  return axios.get('admin/tm_trade_local_lib/' + id)
}

export function putAdminTmSaleLocal(id, params) {
  return axios.put('admin/tm_trade_local_lib/' + id, qs.stringify(params))
}
export function postAdminTmSaleLocal2Epower(id) {
  return axios.put('admin/tm_trade_local_lib/return_epower/' + id)
}

/**
 * 域名产品
 * @param {Function} getDomainSuffixes     获取列表
 * @param {Function} putDomainSuffixes     修改
 * @param {Function} deleteDomainSuffixes  删除
 * @param {Function} sortDomainSuffixes    排序获取商标分类
 *
 */

export function getDomainSuffixes(params) {
  return axios.get(`${API.adminDomainSuffixes}`, params)
}
export function putDomainSuffixes(id, params) {
  return axios.put(
    `${API.adminDomainSuffixes}` + '/' + id,
    qs.stringify(params)
  )
}

export function deleteDomainSuffixes(id) {
  return axios.delete(`${API.adminDomainSuffixes}` + '/' + id)
}

export function sortDomainSuffixes(params) {
  return axios.get(`${API.adminDomainSuffixes}` + '?parent_class=' + params)
}
/**
 * SSL证书
 * @param {Function} getSslTags         标签列表
 * @param {Function} getSslProducts     获取列表
 * @param {Function} putSslProducts     修改
 * @param {Function} deleteSslProducts  删除
 *
 */
export function getSslTags(params) {
  return axios.get(`${API.adminSslTags}`, params)
}
export function getSslProducts(params) {
  return axios.get(`${API.adminSslProducts}`, params)
}
export function putSslProducts(id, params) {
  return axios.put(`${API.adminSslProducts}` + '/' + id, qs.stringify(params))
}

export function deleteSslProducts(id) {
  return axios.delete(`${API.adminSslProducts}` + '/' + id)
}

/**
 * 云虚拟主机
 *
 * 线路
 * @param {Function} getVirtualHostLines        获取
 * @param {Function} getVirtualHostLinesDetail  获取线路详情
 * @param {Function} putVirtualHostLines        修改
 *
 * 产品组
 * @param {Function} getVirtualHostGroups       获取列表
 * @param {Function} putVirtualHostGroups       修改
 *
 * 套餐
 * @param {Function} getVirtualHostPackages     获取列表
 * @param {Function} putVirtualHostPackages     修改
 *
 * CMS
 * @param {Function} getVirtualHostCms          获取列表
 * @param {Function} putVirtualHostCms          修改
 *
 */

export function getVirtualHostLines(params) {
  return axios.get(`${API.adminVirtualHostLines}`, params)
}
export function getVirtualHostLinesDetail(id) {
  return axios.get(`${API.adminVirtualHostLines}` + '/' + id)
}
export function putVirtualHostLines(id, params) {
  return axios.put(
    `${API.adminVirtualHostLines}` + '/' + id,
    qs.stringify(params)
  )
}

export function getVirtualHostGroups(params) {
  return axios.get(`${API.adminVirtualHostGroups}`, params)
}
export function putVirtualHostGroups(id, params) {
  return axios.put(
    `${API.adminVirtualHostGroups}` + '/' + id,
    qs.stringify(params)
  )
}

export function getVirtualHostPackages(params) {
  return axios.get(`${API.adminVirtualHostPackages}`, params)
}
export function putVirtualHostPackages(id, params) {
  return axios.put(
    `${API.adminVirtualHostPackages}` + '/' + id,
    qs.stringify(params)
  )
}

export function getVirtualHostCms(params) {
  return axios.get(`${API.adminVirtualHostCms}`, params)
}
export function putVirtualHostCms(id, params) {
  return axios.put(
    `${API.adminVirtualHostCms}` + '/' + id,
    qs.stringify(params)
  )
}
/**
 * 域名交易 TODO  库 还没有同步过来，打算到时候做具体业务的时候再同步
 * @param {Function} getDomainTrade     获取列表
 * @param {Function} putDomainTrade     修改
 * @param {Function} deleteDomainTrade  删除
 * @param {Function} syncDomainTrade    同步域名交易数据
 * @param {Function} getCloudDts    云域名交易列表
 * @param {Function} getLocalDts    本地域名交易列表
 *
 */
export function getDomainTrade(params) {
  return axios.get(`${API.adminDomainTrade}`, params)
}
export function putDomainTrade(id, params) {
  return axios.put(`${API.adminDomainTrade}` + '/' + id, qs.stringify(params))
}
export function deleteDomainTrade(id) {
  return axios.delete(`${API.adminDomainTrade}` + '/' + id)
}
export function syncDomainTrade(params) {
  return axios.post(`${API.adminDomainTradeSync}`, params)
}

export function getCloudDts(params) {
  return axios.get(`${API.adminCloudDts}`, params)
}

export function getLocalDts(params) {
  return axios.get(`${API.adminLocalDts}`, params)
}
export const getCloudDetail = (id) => { return axios.get(`${API.adminCloudDts}` + '/' + id) }
export const putCloudDetail = (id, params) => { return axios.put(`${API.adminCloudDts}` + '/' + id, params) }
export const deleteCloud = (id) => { return axios.delete(`${API.adminCloudDts}` + '/' + id) }

export const getLocalDetail = (id) => { return axios.get(`${API.adminLocalDts}` + '/' + id) }
export const putLocalDetail = (id, params) => { return axios.put(`${API.adminLocalDts}` + '/' + id, params) }
export const deleteLocal = (id) => { return axios.delete(`${API.adminLocalDts}` + '/' + id) }
/**
 * 邮箱
 * @param {Function} getEmailProducts     获取列表
 * @param {Function} putEmailProducts     修改
 * @param {Function} deleteEmailProducts  删除
 *
 */
export function getEmailProducts(params) {
  return axios.get(`${API.adminEmail}`, params)
}
export function putEmailProducts(id, params) {
  return axios.put(`${API.adminEmail}` + '/' + id, qs.stringify(params))
}
export function deleteEmailProducts(id) {
  return axios.delete(`${API.adminEmail}` + '/' + id)
}
/**
 * 官微建站
 * @param {Function} getGW               获取列表
 * @param {Function} getGWTemplete       获取模板列表
 * @param {Function} getGWTempleteClass  获取模板分类
 * @param {Function} postGWTemplete      创建为模板
 * @param {Function} deleteGWTemplete    模板删除
 * 类型 common：公共模板 customize：自定义模板
 */
export function getGW() {
  return axios.get(`${API.adminGW}`)
}
export function getGWTemplete(params) {
  return axios.get(`${API.adminGWTemplete}`, { params })
}
export function getGWTempleteClass() {
  return axios.get(`${API.adminGWTempleteClass}`)
}
export function syncGWTempleteClass() {
  return axios.post(`${API.adminGWTempleteClass}/sync`)
}
export function postGWTemplete(id, params) {
  return axios.post(`${API.adminGWTemplete}` + '/websites/' + id, params, {
    headers: {
      'Content-Type': 'multipart/form-data; charset=utf-8'
    },
    processData: false,
    contentType: false
  })
}
export function deleteGWTemplete(id) {
  return axios.delete(`${API.adminGWTemplete}` + '/' + id)
}
/**
 * 官微建站案例
 * @param {Function} addGWExamples     新增
 * @param {Function} getGWExamples     获取列表
 * @param {Function} putGWExamples     修改
 * @param {Function} deleteGWExamples  删除
 *
 */
export function addGWExamples(params) {
  return axios.post(`${API.adminGWExamples}`, params)
}
export function getGWExamples() {
  return axios.get(`${API.adminGWExamples}`)
}
export function putGWExamples(id, params) {
  return axios.put(`${API.adminGWExamples}` + '/' + id, qs.stringify(params))
}
export function deleteGWExamples(id) {
  return axios.delete(`${API.adminGWExamples}` + '/' + id)
}

/**
 * 云服务器
 * @param {Function} getServerLines     获取列表
 * @param {Function} putServerLines     修改
 *
 * @param {Function} getServerSystemClass     获取系统分类
 * @param {Function} getServerSystem     获取系统列表
 *
 */
export function getServerLines() {
  return axios.get(`${API.adminServerLines}`)
}
export function putServerLines(id, params) {
  return axios.put(`${API.adminServerLines}` + '/' + id, qs.stringify(params))
}

export function getServerSystemClass() {
  return axios.get(`${API.adminServerClass}`)
}
export function getServerSystem() {
  return axios.get(`${API.adminServerSystem}`)
}

/**
 * 小程序
 * @param {Function} getMiniProducts     获取产品列表
 * @param {Function} putMiniProducts     修改产品
 *
 * @param {Function} getMiniPermissions     获取权限列表
 * @param {Function} putMiniPermissions     修改权限
 *
 */
export function getMiniProducts() {
  return axios.get(`${API.adminMiniProducts}`)
}
export function putMiniProducts(id, params) {
  return axios.put(`${API.adminMiniProducts}` + '/' + id, qs.stringify(params))
}

export function getMiniPermissions() {
  return axios.get(`${API.adminMiniPermissions}`)
}
export function putMiniPermissions(id, params) {
  return axios.put(
    `${API.adminMiniPermissions}` + '/' + id,
    qs.stringify(params)
  )
}
