/**
 * @Name          : ePower
 * @Author        : feng
 * @Version       : 1.0.0
 * @Update        : 2019-12-09
 * @direction     : 站务管理
 */
import API from '../api' // 导入接口域名列表
import axios from '@/utils/request' // 导入http中创建的axios实例
import qs from 'qs' // 根据需求是否导入qs模块

/**
 * 公告列表
 * @param {Function} getAnnouncements 获取公告列表
 * @param {Function} getAnnouncementDetail 获取公告详情
 * @param {Function} addAnnouncements 新增公告
 * @param {Function} updateAnnouncements 修改公告
 * @param {Function} deleteAnnouncements 删除公告
 */
export function getAnnouncements(type) {
  return axios.get(`${API.announcements}` + '?category_id=' + type)
}

export function getAnnouncementDetail(id) {
  return axios.get(`${API.announcements}` + '/' + id)
}

export function addAnnouncements(params) {
  return axios.post(`${API.announcements}`, qs.stringify(params))
}

export function updateAnnouncements(id, params) {
  return axios.put(`${API.announcements}` + '/' + id, params)
}

export function deleteAnnouncements(id) {
  return axios.delete(`${API.announcements}` + '/' + id)
}
/**
 * 公告分类
 * @param {Function} getAnnouncementCategories 获取公告分类
 * @param {Function} addAnnouncementCategories 新增公告分类
 * @param {Function} updateAnnouncementCategories 修改公告分类
 * @param {Function} deleteAnnouncementCategories 删除公告分类
 *
 */
export function getAnnouncementCategories() {
  return axios.get(`${API.announcementCategories}`)
}

export function addAnnouncementCategories(params) {
  return axios.post(`${API.announcementCategories}`, qs.stringify(params))
}

export function updateAnnouncementCategories(id, params) {
  return axios.put(`${API.announcementCategories}` + '/' + id, qs.stringify(params))
}

export function deleteAnnouncementCategories(id) {
  return axios.delete(`${API.announcementCategories}` + '/' + id)
}
/**
 * 资讯分类
 * @param {Function} getNewsCategories 获取资讯分类
 * @param {Function} addNewsCategories 新增资讯分类
 * @param {Function} updateNewsCategories 修改资讯分类
 * @param {Function} deleteNewsCategories 删除资讯分类
 */
export function getNewsCategories() {
  return axios.get(`${API.newsCategories}`)
}

export function addNewsCategories(params) {
  return axios.post(`${API.newsCategories}`, params)
}

export function updateNewsCategories(id, params) {
  return axios.put(`${API.newsCategories}` + '/' + id, qs.stringify(params))
}

export function deleteNewsCategories(id) {
  return axios.delete(`${API.newsCategories}` + '/' + id)
}

/**
 * 资讯列表
 * @param {Function} getNews 获取资讯列表
 * @param {Function} getNewsDetail 获取资讯详情
 * @param {Function} addNews 新增资讯
 * @param {Function} updateNews 修改资讯
 * @param {Function} deleteNews 删除资讯
 *
 */
export function getNews(type) {
  return axios.get(`${API.news}` + '?category_id=' + type)
}

export function getNewsDetail(id) {
  return axios.get(`${API.news}` + '/' + id)
}

export function addNews(params) {
  return axios.post(`${API.news}`, qs.stringify(params))
}

export function updateNews(id, params) {
  return axios.put(`${API.news}` + '/' + id, qs.stringify(params))
}

export function deleteNews(id) {
  return axios.delete(`${API.news}` + '/' + id)
}

/**
 * 友情链接
 * @param {Function} getLinks 获取列表
 * @param {Function} addLinks 新增
 * @param {Function} updateLinks 修改
 * @param {Function} deleteLinks 删除
 * @param {Function} sortLinks 排序
 */
export function getLinks() {
  return axios.get(`${API.links}`)
}

export function addLinks(params) {
  return axios.post(`${API.links}`, qs.stringify(params))
}

export function updateLinks(id, params) {
  return axios.put(`${API.links}` + '/' + id, qs.stringify(params))
}

export function deleteLinks(id) {
  return axios.delete(`${API.links}` + '/' + id)
}

export function sortLinks(params) {
  return axios.post(`${API.links}` + '/order', qs.stringify(params))
}

/**
 * 帮助分类
 * @param {Function} getHelpClass     获取列表
 * @param {Function} addHelpClass     新增
 * @param {Function} updateHelpClass  修改
 * @param {Function} deleteHelpClass  删除
 * @param {Function} sortHelpClass   排序
 * @param {Function} syncHelpClass   同步帮助分类
 *
 */
export function getHelpClass() {
  return axios.get(`${API.helpClass}`)
}

export function addHelpClass(params) {
  return axios.post(`${API.helpClass}`, qs.stringify(params))
}

export function updateHelpClass(id, params) {
  return axios.put(`${API.helpClass}` + '/' + id, qs.stringify(params))
}

export function deleteHelpClass(id) {
  return axios.delete(`${API.helpClass}` + '/' + id)
}

export function sortHelpClass(params) {
  return axios.post(`${API.helpClass}` + '/order', qs.stringify(params))
}
export function syncHelpClass(config) {
  return axios.post(`${API.helpClassSync}`, null, config || {})
}

/**
 * 帮助文章
 * @param {Function} getHelp            获取列表
 * @param {Function} addHelp            新增
 * @param {Function} updateHelp         修改
 * @param {Function} deleteHelp         删除
 * @param {Function} getHelpDetail      获取详情
 * @param {Function} syncHelp           同步帮助
 * @param {Function} getHelpLocal       图片待本地化的帮助列表
 * @param {Function} putHelpLocal       帮助文档内容 图片本地化
 */
export function getHelp(params) {
  return axios.get(`${API.help}`, params)
}

export function addHelp(params) {
  return axios.post(`${API.help}`, qs.stringify(params))
}

export function updateHelp(id, params) {
  return axios.put(`${API.help}` + '/' + id, qs.stringify(params))
}

export function deleteHelp(id) {
  return axios.delete(`${API.help}` + '/' + id)
}

export function getHelpDetail(id) {
  return axios.get(`${API.help}` + '/' + id)
}

export function syncHelp(config) {
  return axios.post(`${API.helpSync}`, null, config || {})
}

export function getHelpLocal(config) {
  return axios.get(`${API.helpLocal}`, config || {})
}
export function postHelpLocal(params, config) {
  return axios.post(`${API.help}` + '/img_localization', params, config || {})
}

/**
 * 单页管理
 * @param {Function} getSinglePage 获取列表
 * @param {Function} addSinglePage 新增
 * @param {Function} updateSinglePage 修改
 * @param {Function} deleteSinglePage 删除
 * @param {Function} getSinglePageDetail 获取详情
 */
export function getSinglePage() {
  return axios.get(`${API.singlePage}`)
}

export function addSinglePage(params) {
  return axios.post(`${API.singlePage}`, qs.stringify(params))
}

export function updateSinglePage(id, params) {
  return axios.put(`${API.singlePage}` + '/' + id, qs.stringify(params))
}

export function deleteSinglePage(id) {
  return axios.delete(`${API.singlePage}` + '/' + id)
}

export function getSinglePageDetail(id) {
  return axios.get(`${API.singlePage}` + '/' + id)
}

/**
 * 用户需求 项目需求
 * @param {Function} getProjectRequirements 获取项目需求列表
 * @param {Function} updateProjectRequirements 修改项目需求
 * @param {Function} getTmQueryRequirements 获取商标需求列表
 * @param {Function} updateTmQueryRequirements 修改商标需求
 * @param {Function} getTmPurchaseRequirements 获取企业需求列表
 * @param {Function} updateTmPurchaseRequirements 修改企业需求
 */
export function getProjectRequirements() {
  return axios.get(`${API.projectRequirements}`)
}

export function updateProjectRequirements(id, params) {
  return axios.put(`${API.projectRequirements}` + '/' + id, qs.stringify(params))
}

export function getTmQueryRequirements() {
  return axios.get(`${API.tmQueryRequirements}`)
}

export function updateTmQueryRequirements(id, params) {
  return axios.put(`${API.tmQueryRequirements}` + '/' + id, qs.stringify(params))
}

export function getTmPurchaseRequirements() {
  return axios.get(`${API.tmPurchaseRequirements}`)
}

export function updateTmPurchaseRequirements(id, params) {
  return axios.put(`${API.tmPurchaseRequirements}` + '/' + id, qs.stringify(params))
}

/**
 * 优惠券管理
 * @param {Function} getCoupons 获取列表
 * @param {Function} addCoupon 新增
 * @param {Function} updateCoupon 修改
 * @param {Function} deleteCoupon 删除
 */
export function getCoupons(params) {
  return axios.get(`${API.coupon}`, params)
}

export function addCoupon(params) {
  return axios.post(`${API.coupon}`, qs.stringify(params))
}
export function getCouponDetail(id) {
  return axios.get(`${API.coupon}` + '/' + id)
}

export function updateCoupon(id, params) {
  return axios.put(`${API.coupon}` + '/' + id, qs.stringify(params))
}

export function deleteCoupon(id) {
  return axios.delete(`${API.coupon}` + '/' + id)
}

