/**
 * @Name          : ePower
 * @Author        : feng
 * @Version       : 1.0.0
 * @Update        : 2019-12-09
 * @direction     : 系统管理
 */
import API from '../api' // 导入接口域名列表
import axios from '../../utils/request' // 导入http中创建的axios实例
import qs from 'qs' // 根据需求是否导入qs模块
/**
 * 权限管理
 * @param {*} id
 */
export function authList(params) {
  return axios.get(`${API.permission}`, params)
}
export function getAuthGroup(params) {
  return axios.get(`${API.permission}`, params)
}
export function createAuth(params) {
  return axios.post(`${API.permission}`, qs.stringify(params))
}
export function editAuth(id, params) {
  return axios.put(`${API.permission}` + '/' + id, qs.stringify(params))
}

export function deleteAuth(id) {
  return axios.delete(`${API.permission}` + '/' + id)
}

/**
 * banner 管理
 * @param {*} id
 * @param {*} params
 */
export function getBanners() {
  return axios.get(`${API.banner}`)
}

export function addBanner(params) {
  return axios.post(`${API.banner}`, params)
}
export function updateBanner(id, params) {
  return axios.put(`${API.banner}` + '/' + id, qs.stringify(params))
}
export function sortBanner(params) {
  return axios.post(`${API.banner}` + '/order', qs.stringify(params))
}

export function deleteBanner(params) {
  return axios.delete(`${API.banner}` + '/' + params)
}

/**
 * 菜单管理
 * @param {*} params
 */
export function menuList(params) {
  return axios.get(`${API.menus}?` + qs.stringify(params))
}
export function menuDetail(id) {
  return axios.get(`${API.menus}` + '/' + id)
}
export function createMenu(params) {
  return axios.post(`${API.menus}`, qs.stringify(params))
}
export function deleteMenu(params) {
  return axios.delete(`${API.menus}` + '/' + params)
}
export function editMenu(id, params) {
  return axios.put(`${API.menus}` + '/' + id, params)
}
export function sortMenu(params) {
  return axios.post(`${API.menus}` + '/order', params)
}
/**
 * 角色管理
 * @param {*} params
 */
export function getRoles(params) {
  return axios.get(`${API.roles}`, qs.stringify(params))
}

export function addRole(params) {
  return axios.post(`${API.roles}`, qs.stringify(params))
}

export function updateRole(id, params) {
  return axios.put(`${API.roles}` + '/' + id, qs.stringify(params))
}
export function getRoleDetail(id) {
  return axios.get(`${API.roles}` + '/' + id)
}

export function deleteRole(id) {
  return axios.delete(`${API.roles}` + '/' + id)
}

/**
 * 管理员管理
 * @param {*} params
 */
export function userList(params) {
  return axios.get(`${API.adminUser}`, params)
}
export function getUserDetail(id) {
  return axios.get(`${API.adminUser}` + '/' + id)
}
export function deleteUser(id, params) {
  return axios.delete(`${API.adminUser}` + '/' + id, params)
}
export function addUser(params) {
  return axios.post(`${API.adminUser}`, qs.stringify(params))
}
export function editUser(id, params) {
  return axios.put(`${API.adminUser}` + '/' + id, qs.stringify(params))
}

/**
 * 消息模板
 */
export function getTemplate(params) {
  return axios.get(`${API.template}`, params)
}
export function editTemplate(id, params) {
  return axios.put(`${API.template}` + '/' + id, params)
}
export function addTemplate(params) {
  return axios.post(`${API.template}`, params)
}
export function deleteTemplate(id, params) {
  return axios.delete(`${API.template}` + '/' + id, params)
}

/**
 * 获取基本配置
 */
export function getConfig(type, hostName) {
  return axios.get(`${API.configs}` + '/' + type + '?host=' + (hostName || ''))
}
export function updateConfig(type, hostName, params) {
  return axios.post(`${API.configs}` + '/' + type + '?host=' + (hostName || ''), params)
}
export function discoverPort(id, key, url) {
  return axios.get(`${API.portDiscover}` + '?api_id=' + id + '&api_key=' + key + '&api_url=' + url)
}
/**
 * 会员等级
 */
export function getLevel(params) {
  return axios.get(`${API.level}`, qs.stringify(params))
}

export function addLevel(params) {
  return axios.post(`${API.level}`, qs.stringify(params))
}

export function updateLevel(id, params) {
  return axios.put(`${API.level}` + '/' + id, qs.stringify(params))
}

export function deleteLevel(params) {
  return axios.delete(`${API.level}` + '/' + params)
}

export function sortLevel(params) {
  return axios.post(`${API.level}` + '/order', qs.stringify(params))
}

/**
 * 菜单管理
 */

export function getNav(type, host) {
  return axios.get(`${API.nav}` + '?type=' + type + '&host=' + (host || ''))
}

export function addNav(params) {
  return axios.post(`${API.nav}`, qs.stringify(params))
}

export function updateNav(id, params) {
  return axios.put(`${API.nav}` + '/' + id, qs.stringify(params))
}

export function deleteNav(params) {
  return axios.delete(`${API.nav}` + '/' + params)
}

export function sortNav(params) {
  return axios.post(`${API.nav}` + '/order', qs.stringify(params))
}

/**
 * 日志
 * @param {*} params
 */
export function getLogList(params) {
  return axios.get(`${API.log}`, { params })
}
export function getAdminLoginList(params) {
  return axios.get('admin/logs/admin_login', { params })
}
export function getUserLogList(params) {
  return axios.get('admin/logs/user_operation', { params })
}
export function getUserLoginList(params) {
  return axios.get('admin/logs/user_login', { params })
}

/**
 * 客服
 * @param {*} params
 */
export function getCustomer(params) {
  return axios.get(`${API.customer}`, qs.stringify(params))
}

export function addCustomer(params) {
  return axios.post(`${API.customer}`, qs.stringify(params))
}

export function updateCustomer(id, params) {
  return axios.put(`${API.customer}` + '/' + id, qs.stringify(params))
}

export function deleteCustomer(params) {
  return axios.delete(`${API.customer}` + '/' + params)
}

/**
 * seo
 * @param {*} params
 */
export function getSeos(params) {
  return axios.get('/admin/route_seos', qs.stringify(params))
}
export function getSeosDetail(id) {
  return axios.get('/admin/route_seos/' + id)
}

export function addSeos(params) {
  return axios.post('/admin/route_seos', qs.stringify(params))
}

export function updateSeos(id, params) {
  return axios.put('/admin/route_seos/' + id, qs.stringify(params))
}

export function deleteSeos(id) {
  return axios.delete('/admin/route_seos/' + id)
}
