import { deepClone } from '@/utils'
import Vue from 'vue'

function showDialog(contents, options) {
  if (options === undefined) {
    options = contents
    contents = options.component || ''
    options.component = null
  }
  options = deepClone(options)
  var $el = null
  var vue = new Vue({
    data: function() {
      return {
        visible: true
      }
    },
    methods: {
      close: function(reason) {
        this.visible = false
        options.close && options.close.call(this, reason)
      }
    },
    render: function(h) {
      var _this = this
      var vNode = h(contents, {
        ref: 'dialog-contents-ref',
        props: options['props'] || {},
        on: {
          'close': function(reason) {
            _this.close(reason)
          },
          'done': function(...args) {
            args.unshift(function() {
              _this.close('done')
            })
            options.done && options.done.apply(this, args)
          }
        }
      })

      var nodes = [vNode]
      var buttons = []
      var buttonDefines = []
      if (options.showCancelButton !== false) {
        buttonDefines.push({
          text: options.cancelButtonText || '取消',
          dialogResult: 'cancel'
        })
      }
      if (options.buttons) {
        buttonDefines = buttonDefines.concat(options.buttons)
      }

      if (options.showConfirmButton !== false) {
        buttonDefines.push({
          text: options.confirmButtonText || '确定',
          type: options.confirmButtonType || 'primary',
          dialogResult: 'confirm'
        })
      }

      for (let i = 0; i < buttonDefines.length; i++) {
        buttons.push((function(button) {
          return h('el-button', {
            props: { type: button.type || 'default' },
            'class': [button.customClass || ''],
            on: {
              click: function() {
                const ref = _this.$refs['dialog-contents-ref']
                if (!ref) {
                  _this.close(button.dialogResult)
                  return
                }
                if (button.dialogResult === 'confirm' && ref.done) {
                  ref.done(function() {
                    _this.close('done')
                  })
                  return
                }
                if (button.dialogResult !== 'cancel' && ref[button.dialogResult]) {
                  ref[button.dialogResult](function() {
                    _this.close(button.dialogResult)
                  })
                  return
                }
                _this.close(button.dialogResult)
              }
            }
          }, button.text)
        })(buttonDefines[i]))
      }

      if (buttons.length > 0) {
        nodes.push(h('div', {
          slot: 'footer',
          'style': {
            textAlign: options['footerAlign'] || 'right',
            boxSizing: 'border-box'
          }
        }, buttons))
      }

      return h(
        'el-dialog',
        {
          staticClass: 'el-dialog__jazor-wrapper',
          'class': {
            'el-dialog__has__footer': buttons.length > 0
          },
          props: {
            visible: _this.visible,
            title: options.title || '',
            width: options.width || '40%',
            top: options.top || '8vh',
            customClass: options.customClass || '',
            closeOnClickModal: options.closeOnClickModal === true,
            showClose: true,
            lockScroll: options.lockScroll === true
          },
          on: {
            'update:visible': function(val) {
              if (val) {
                _this.visible = true
                return
              }
              _this.close('close')
            },
            'close': function() {
              _this.visible = false
              vue.$destroy()
              document.body.removeChild($el)
              $el = null
            }
          }
        },
        nodes
      )
    }
  })
  vue.$mount()
  document.body.appendChild($el = vue.$el)
  return {
    close: function() {
      vue.close && vue.close()
    }
  }
}
export function input(value, options) {
  options = options || {}
  showDialog({
    data() {
      return {
        inputValue: value
      }
    },
    render(h) {
      var _this = this
      return h('el-input', {
        props: { value: this.inputValue },
        on: {
          'input': function(value) {
            _this.inputValue = value
          }
        }
      })
    },
    methods: {
      done(done) {
        this.$emit('done', this.inputValue)
      }
    }
  },
  {
    done: options.done || function(done) { done() },
    close: options.close || function() {},
    title: options.title || '',
    width: options.width || undefined,
    confirmButtonText: options.buttonText || '',
    confirmButtonType: options.buttonType || ''
  })
}
export default {
  install(Vue) {
    Vue.prototype.$showAny = showDialog
  }
}
