import { deepClone } from '@/utils'

export default {
  install(Vue) {
    const Groups = {
      user: ['user', 'aizhan', 'eb', 'qcc'],
      tm: ['tm'],
      aizhan: ['aizhan'],
      eb: ['eb'],
      qcc: ['qcc'],
      normal: ['user', 'tm'],
      demo: ['demo']
    }
    Vue.prototype.$checkPermission = function(group) {
      const env = process.env.VUE_APP_ENV
      const permission = Groups[group]
      if (Array.isArray(permission)) {
        return permission.indexOf(env) >= 0
      }
      return permission === env
    }
    Vue.component('view-permission', {
      props: {
        // 标签渲染
        htmlTag: {
          type: String,
          default: 'span'
        },
        // 包含 OR 排除
        isInclude: {
          type: Boolean,
          default: true
        },
        // 权限组
        verifyGroup: {
          type: String,
          default: null
        }
      },
      data() {
        return {
          /* 当前爱站为普通版，后期切换tm版，只要把user组的aizhan放到tm组即可*/
          groups: deepClone(Groups),
          permission: null
        }
      },
      methods: {
        // 检测当前权限是否符合
        checkPermission() {
          const env = process.env.VUE_APP_ENV
          const permission = this.permission
          if (Array.isArray(permission)) {
            if (this.isInclude) {
              return permission.indexOf(env) >= 0
            } else {
              return permission.indexOf(env) === -1
            }
          }
          if (this.isInclude) {
            return permission === env
          } else {
            return permission !== env
          }
        }
      },
      render(h) {
        if (!this.permission && !this.verifyGroup) {
          // eslint-disable-next-line no-throw-literal
          throw 'attr \'permission\' or \'verify-group\' is missing'
        }
        if (this.verifyGroup) {
          if (!this.groups.hasOwnProperty(this.verifyGroup)) {
            // eslint-disable-next-line no-throw-literal
            throw 'group not found: ' + this.verifyGroup
          }
        }
        if (!this.permission) {
          if (!this.verifyGroup) {
            // eslint-disable-next-line no-throw-literal
            throw 'attr \'verify-group\' is missing'
          }
          this.permission = this.groups[this.verifyGroup]
        } else if (this.verifyGroup) {
          this.permission = this.groups[this.verifyGroup]
        }
        if (!this.checkPermission()) {
          return h('')
        }
        const slots = this.$slots.default
        if (!Array.isArray(slots) || slots.length === 0) {
          return h('')
        }
        if (slots.length === 1) {
          return slots[0]
        }
        return h(this.htmlTag, slots)
      }
    })
  }
}
