// 处理路由权限
import adminRouterData from '@/router/modules/admin'

import { getUserInfo } from '@/api/modules/common'

import routerMap from '@/router/router-map' // 路由映射表
import customRouterMap from '@/router/router-map-customize' // 路由映射表
import Layout from '@/layout/index'
import { deepClone } from '@/utils'

/**
 * 数据由后端返回
 * 递归处理子菜单
 * @param data
 */
function filterAsyncRouter(data) {
  // 遍历后台传来的路由字符串，转换为组件对象
  return data.filter(route => {
    if (route.component === 'Layout') {
      route.component = Layout
    } else {
      // 只会返回处理好的函数
      if (route.component) {
        if (route.component.indexOf('/customize') === 0) {
          route.component = customRouterMap(route.component.substr(11))
        } else {
          route.component = routerMap(route.component)
        }
      } else {
        route.component = routerMap('notFound')
      }
    }
    if (route.children && route.parent_id !== 0) {
      route.alwaysShow = true
    }
    // 处理后台的数据
    if (!route.meta) {
      route.meta = {
        title: route.title,
        icon: route.icon,
        id: route.id + '',
        parent_id: route.parent_id + ''
      }
      if (route.active_path) {
        route.meta.activeMenu = route.active_path
      }
      // 新增name 组件唯一标识
      delete route.active_path
      delete route.title
      delete route.icon
    } else {
      route.meta.id = route.id + ''
      route.meta.parent_id = route.parent_id + ''
    }
    // slug => name

    // 设定路由的名字，一定要填写不然使用<keep-alive>时会出现各种问题
    route.name = route.slug

    // 当设置 true 的时候该路由不会再侧边栏出现 如401，login等页面，或者如一些编辑页面/edit/1
    route.hidden = route.is_hidden

    delete route.slug
    delete route.is_hidden
    // TODO 这里暂时使用路由的 base 属性
    if (route.path) {
      // route.path = '/admin' + route.path
    } else {
      route.path = '/admin/' + route.name
    }
    if (route.children && route.children.length) {
      route.children = filterAsyncRouter(route.children)
    }
    return true
  })
}

const state = {
  routes: [], // 总路由
  addRoutes: [], // 新增的路由
  permissionRoutes: [], // 三级路由 第一级在顶部 侧边栏 显示二级路由和三极路由
  routerIndex: '', // 顶部导航高亮
  permissions: {} // 当前用户的 map 权限
}
const mutations = {
  SET_ROUTES: (state, data) => {
    state.routes = data
  },
  SET_ADD_ROUTES: (state, data) => {
    state.addRoutes = data
  },
  SET_ROUTER_INDEX: (state, index) => {
    state.routerIndex = index
  },
  SET_PERMISSION_ROUTES: (state, data) => {
    state.permissionRoutes = data
  },
  SET_PERMISSIONS: (state, data) => {
    state.permissions = data
  }
}

const actions = {
  switchMenu({ state, commit }, index) {
    const temp = state.addRoutes.filter(v => {
      return v.meta && (v.meta.id === index)
    })
    const data = temp[0].children
    commit('SET_ROUTER_INDEX', index)
    commit('SET_PERMISSION_ROUTES', data)
  },
  setRouterIndex({ commit, state }, to) {
    const data = state.addRoutes
    const parent_id = parseInt(to.meta.parent_id)
    // 简单粗暴的三层搜索
    const select = (item, parent_id) => {
      // 先查第一层
      const data1 = item
      let target = ''
      for (let index1 = 0; index1 < data1.length; index1++) {
        const v1 = data1[index1]
        if (v1.id === parent_id) {
          target = v1
          break
        }
        const data2 = v1.children
        if (!data2) {
          continue
        }
        for (let index2 = 0; index2 < data2.length; index2++) {
          const v2 = data2[index2]
          if (v2.id === parent_id) {
            target = v1
            break
          }
          const data3 = v2.children
          if (!data3) {
            continue
          }
          for (let index3 = 0; index3 < data3.length; index3++) {
            const v3 = data3[index3]
            if (v3.id === parent_id) {
              target = v1
              break
            }
          }
        }
      }
      return target
    }
    const target = select(data, parent_id)
    commit('SET_ROUTER_INDEX', target.id + '')
    commit('SET_PERMISSION_ROUTES', target.children)
  },
  /**
   * 1、获取用户信息
   * 2、初始化路由数据
   * @param {*} param0
   * @returns
   */
  getInfo({ commit, rootState }) {
    return new Promise((resolve, reject) => {
      getUserInfo().then(res => {
        const info = res.data.data
        const routes = info.menus
        rootState.user.userInfo = deepClone(info)

        const permissions = info.permissions

        let accessedRoutes = []
        accessedRoutes = filterAsyncRouter(routes || [])
        accessedRoutes.push({ path: '*', redirect: '/404', hidden: true })

        const routesTemp = adminRouterData.concat(accessedRoutes)
        const temp = {}

        for (let index = 0; index < permissions.length; index++) {
          const v = permissions[index]
          temp[v.slug] = v
        }
        commit('SET_PERMISSIONS', temp)
        commit('SET_ROUTES', routesTemp)
        commit('SET_ADD_ROUTES', accessedRoutes)

        rootState.user.name = info.name
        resolve(accessedRoutes)
      }).catch((error) => {
        reject(error)
      })
    })
  }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}
