import qs from 'qs'
import Vue from 'vue' // 根据需求是否导入qs模块

/**
 * Parse the time to string
 * @param {(Object|string|number)} time
 * @param {string} cFormat
 * @returns {string}
 */
export function parseTime(time, cFormat) {
  if (arguments.length === 0) {
    return null
  }
  const format = cFormat || '{y}-{m}-{d} {h}:{i}:{s}'
  let date
  if (typeof time === 'object') {
    date = time
  } else {
    if ((typeof time === 'string') && (/^[0-9]+$/.test(time))) {
      time = parseInt(time)
    }
    if ((typeof time === 'number') && (time.toString().length === 10)) {
      time = time * 1000
    }
    date = new Date(time)
  }
  const formatObj = {
    y: date.getFullYear(),
    m: date.getMonth() + 1,
    d: date.getDate(),
    h: date.getHours(),
    i: date.getMinutes(),
    s: date.getSeconds(),
    a: date.getDay()
  }
  const time_str = format.replace(/{(y|m|d|h|i|s|a)+}/g, (result, key) => {
    let value = formatObj[key]
    // Note: getDay() returns 0 on Sunday
    if (key === 'a') { return ['日', '一', '二', '三', '四', '五', '六'][value ] }
    if (result.length > 0 && value < 10) {
      value = '0' + value
    }
    return value || 0
  })
  return time_str
}

/**
 * This is just a simple version of deep copy
 * Has a lot of edge cases bug
 * If you want to use a perfect deep copy, use lodash's _.cloneDeep
 * @param {Object} source
 * @returns {Object}
 */
export function deepClone(source) {
  if (!source && typeof source !== 'object') {
    throw new Error('error arguments', 'deepClone')
  }
  const targetObj = source.constructor === Array ? [] : {}
  Object.keys(source).forEach(keys => {
    if (source[keys] && typeof source[keys] === 'object') {
      targetObj[keys] = deepClone(source[keys])
    } else {
      targetObj[keys] = source[keys]
    }
  })
  return targetObj
}
export function gotoUser(id, redirect) {
  Vue.prototype.$api.user.getAuthRedirect(id).then(res => {
    let url = res.data.data.url
    if (redirect) {
      url = url + '&redirect=' + redirect
    }
    window.open(url)
  })
}

/**
 * [getParam ]
 * @param  {String} name
 * @param  {String} url   [default:location.href]
 * @return {String|Boolean}
 */
export function getParam(name, url) {
  if (typeof name !== 'string') return false
  if (!url) url = window.location.href
  // 当遇到name[xx]时，对方括号做一下转义为 name\[xxx\]，因为下面还需要使用name做正则
  name = name.replace(/[\[\]]/g, '\\$&')
  var regex = new RegExp('[?&]' + name + '(=([^&#]*)|&|#|$)')
  var results = regex.exec(url)
  if (!results) return null
  if (!results[2]) return ''
  return decodeURIComponent(results[2].replace(/\+/g, ' '))
}

export function handleExport(url, params) {
  const query = deepClone(params)
  if (query.pay_status === -1 || query.pay_status === '-1') {
    query.pay_status = ''
  }
  const href = '/v1/' + url + '/export?' + qs.stringify(query)
  window.open(href)
}

export function refreshPage(that) {
  if (!that || !that.$route) {
    return
  }
  const { fullPath } = that.$route
  that.$router.replace({
    path: '/redirect' + fullPath
  })
}

export function mergeOptions(defaults, config) {
  const options = {}
  let key
  for (key in defaults) {
    options[key] = defaults[key]
  }
  for (key in config) {
    if (!config.hasOwnProperty(key)) continue

    const value = config[key]
    if (typeof value === 'undefined') continue
    options[key] = value
  }
  return options
}

export function createQueryData(basicQuery, newQuery) {
  for (var name in basicQuery) {
    if (!basicQuery.hasOwnProperty(name)) continue
    if (!newQuery.hasOwnProperty(name)) continue
    if (typeof basicQuery[name] === 'number') {
      if (newQuery[name]) basicQuery[name] = parseInt(newQuery[name])
      continue
    }
    basicQuery[name] = newQuery[name]
  }
  return basicQuery
}

export default {
  install(Vue) {
    Vue.prototype.deepClone = deepClone
    Vue.prototype.getParam = getParam
    Vue.prototype.refreshPage = refreshPage
    Vue.prototype.goToUser = gotoUser
    Vue.prototype.handleExport = handleExport
  }
}
