// common
import * as common_index from './modules/common/index'
import * as captcha from './modules/common/captcha'
import * as price from './modules/common/price'
import * as order from './modules/common/order'
// home
import * as article from './modules/home/article'
import * as gw from './modules/home/gw'
import * as vhost from './modules/home/vhost'
import * as xcx from './modules/home/xcx'

import * as ssl from './modules/ssl'
import axios from '../utils/request' // 导入http中创建的axios实例

// 商标
import * as trademark from './modules/tm'
import API from './api'
import qs from 'qs'

const common = Object.assign(common_index, captcha, price, order)
const home = Object.assign({}, article, gw, vhost, xcx)
const tm = Object.assign({}, trademark)

const require_cache = {}
function parseResponse(data, $config) {
  const module = { exports: {}};
  (new Function('module', 'exports', data))(module, module.exports)
  if ($config && $config.flat === true) {
    const idName = $config['id'] || 'id'
    const parentIdName = $config['parent_id'] || 'parent_id'
    const data = module.exports
    if (!(data instanceof Array)) return module.exports

    const result = { maps: {}, datas: {}}; let item = null; let parent_id

    const maps = result.maps
    const datas = result.datas
    for (let i = 0; i < data.length; i++) {
      item = data[i]
      parent_id = item[parentIdName]
      datas[item[idName]] = item
      if (!maps.hasOwnProperty(parent_id)) {
        maps[parent_id] = []
      }
      maps[parent_id].push(item)
    }
    return result
  }
  return module.exports
}
export function require($url, $config) {
  $config = $config || {}
  let cache_tag = $url
  if ($config.hasOwnProperty('fixExports') && $config['fixExports']) {
    cache_tag = $url + '--' + ($config['fixExports'] instanceof Array ? $config['fixExports'].join('__') : $config['fixExports'])
  }
  if (require_cache.hasOwnProperty(cache_tag)) {
    return new Promise((resolve, reject) => {
      resolve(parseResponse(require_cache[cache_tag], $config))
    })
  }
  const axiosConfig = {
    baseURL: '/',
    responseType: 'text',
    validateStatus: statusCode => true,
    ignoreInterceptors: true
  }

  if ($config.hasOwnProperty('processMessage') && $config['processMessage']) {
    axiosConfig['processMessage'] = $config['processMessage']
  }
  return axios.get($url, axiosConfig).then(function(response) {
    if ($config.hasOwnProperty('fixExports') && $config['fixExports']) {
      const fixExports = $config['fixExports']
      if (fixExports instanceof Array) {
        response += ';\r\nmodule.exports = {' + fixExports.join(', ') + '};'
      } else {
        response += ';\r\nmodule.exports = ' + $config['fixExports'] + ';'
      }
    }
    require_cache[cache_tag] = response
    return parseResponse(response, $config)
  })
}

function get(url, params, config) {
  url = url.replace(/\?$/, '')

  const cache = config && config.hasOwnProperty('cache') && config['cache'] === true

  url = url + (params ? (url.indexOf('?') === -1 ? '?' : '&') + qs.stringify(params) : '')

  if (cache && __axios_cache__.hasOwnProperty(url) && __axios_cache__[url]) {
    return Promise.resolve(__axios_cache__[url])
  }

  return axios.get(url, config || {}).then(res => {
    if (cache) __axios_cache__[url] = res
    return res
  })
}
const __axios_cache__ = {}
const service = {
  endpoints: API,
  common,
  home,
  tm,
  ssl,
  getRaw(url, params, config) {
    config = config || {}
    config.returnRaw = true
    return get(url, params, config)
  },
  get,
  post(url, params, config) {
    return axios.post(url, qs.stringify(params), config || {})
  },
  put(url, params, config) {
    return axios.put(url, qs.stringify(params), config || {})
  },
  delete(url, params, config) {
    url = url.replace(/\?$/, '')
    return axios.delete(url + (params ? (url.indexOf('?') === -1 ? '?' : '&') + qs.stringify(params) : ''), config || {})
  },
  require,
  upload(url, fields, config) {
    config = config || {}
    if (!config.headers) {
      config.headers = {}
    }
    config.headers['Content-Type'] = 'multipart/form-data'
    return axios.post(url, fields, config)
  }
}
export {
  service
}
export default {
  install(Vue) {
    Vue.prototype.$api = service
  }
}
