/*
 * @Author: fengzg
 * @Date: 2020-01-14 15:35:08
 * @LastEditors: fengzg
 * @LastEditTime: 2020-06-03 20:07:36
 * @FilePath: \vue-complete\src\api\modules\common\index.js
 * @Description: 通用模块
 * @WebSite: https://www.epower.cn/
 */

import API from '../../api'
import axios from '@/utils/request' // 导入http中创建的axios实例
import qs from 'qs'

/**
 * 获取系统设置
 * @param {Function} getSetting  获取基本配置
 * @param {Function} getEpEncrypt 加密字符串
 * @param {Function} getEpDecrypt 解密字符串
 */
export function getSetting(params) {
  return axios.get(`${API.setting}`, params)
}

export function getEpEncrypt(params) {
  return axios.post(`${API.epEncrypt}`, params)
}
export function getEpDecrypt(params) {
  return axios.post(`${API.epDecrypt}`, params)
}

/**
 * token 登录
 * @param {Function} getServerToken 获取服务端token
 * @param {Function} removeServerToken   删除token
 * @param {Function} refreshServerToken   刷新token
 * @param {Function} switchLogin          切换登录
 */

export function getServerToken(params) {
  return axios.post(`${API.token}`, qs.stringify(params))
}
export function removeServerToken(params) {
  return axios.delete(`${API.tokenInfo}`, qs.stringify(params))
}
export function refreshServerToken() {
  return axios.put(`${API.tokenInfo}`)
}
export function switchLogin(params) {
  return axios.post(`${API.switchLogin}`, qs.stringify(params))
}
/**
 * 修改用户信息
 * @param {Function} getUserInfo   获取用户信息
 */
export function getUserInfo() {
  return axios.get(`${API.users}` + '/current')
}
/**
 * 注册 找回密码
 * @param {Function} register 注册
 * @param {Function} unique 验证手机号是否合法
 * @param {Function} exist  验证手机号\email\用户名 唯一性
 * @param {Function} updatePassword 找回密码
 *
 */
export function register(params) {
  return axios.post(`${API.register}`, qs.stringify(params))
}
export function unique(params) {
  return axios.get(`${API.unique}`, params)
}
export function exist(params) {
  return axios.get(`${API.exist}`, params)
}
export function updatePassword(params) {
  return axios.post(`${API.password}`, qs.stringify(params))
}

/**
 * @param {Function} postWechatCode   获取微信二维码
 * @param {Function} getWechatCode    验证扫码结果
 */
export function postWechatCode() {
  return axios.post(`${API.wechat}`)
}
export function getWechatCode(params) {
  return axios.get(`${API.wechat}` + '?flag=' + params)
}

/**
 * @param {Function} getBanner 获取banner
 */
export function getBanner(params) {
  return axios.get(`${API.banner}` + '/' + params)
}

/**
 * @param {Function} getCustomer  客服列表
 */
export function getCustomer() {
  return axios.get(`${API.customer}`)
}
/**
 * @param {Function} getWebsiteLinks 友情链接
 */
export function getWebsiteLinks() {
  return axios.get(`${API.websiteLinks}`)
}

/**
 * @param {Function} getNavigations  获取顶部导航\底部导航
 */

export function getNavigations() {
  return axios.get(`${API.navigations}`)
}

/**
 * 提交项目需求
 * @param {Function} postProjectRequirements 项目需求
 * @param {Function} postTmQueryRequirements 商标查询需求
 * @param {Function} postTmPurchaseRequirements 商标购买需求
 */
export function postProjectRequirements(params) {
  return axios.post(`${API.projectRequirements}`, qs.stringify(params))
}
export function postTmQueryRequirements(params) {
  return axios.post(`${API.tmQueryRequirements}`, qs.stringify(params))
}
export function postTmPurchaseRequirements(params) {
  return axios.post(`${API.tmPurchaseRequirements}`, qs.stringify(params))
}

/**
 * @param {Function} getSinglePages 获取单页
 * @param {Function} getSinglePageDetail 获取单页内容
 */
export function getSinglePages() {
  return axios.get(`${API.singlePages}`)
}
export function getSinglePageDetail(type) {
  return axios.get(`${API.singlePages}` + '/' + type)
}
/**
 * @param {Function} getCoupons 获取优惠券列表
 */
export function getCoupons() {
  return axios.get(`${API.coupons}`)
}

export function getVariables(scope) {
  return axios.get('/platform_variables',{ baseURL: '/', params: { vars: scope || 'mobile,version,banners' }})
}
