/*
 * @Author: fengzg
 * @Date: 2020-05-11 17:18:53
 * @LastEditors: fengzg
 * @LastEditTime: 2020-05-22 14:52:33
 * @FilePath: \vue-complete\src\api\modules\user\order.js
 * @Description:
 * @WebSite: https://www.epower.cn/
 */
import API from '../../api'
import axios from '@/utils/request' // 导入http中创建的axios实例
import qs from 'qs' // 根据需求是否导入qs模块

/**
 * @description: 创建订单
 * @param {Function} createOrder 创建订单
 * @param {Function} payOrder 支付订单
 */
export function createOrder(params) {
  return axios.post(`${API.createOrder}`, qs.stringify(params))
}
export function payOrder(params) {
  return axios.post(`${API.payOrder}`, qs.stringify(params))
}

/**
 * 官微建站订单
 * @param {Function} createOrderGwOpen        开通官微建站
 * @param {Function} createOrderGwDomain      域名绑定数量
 * @param {Function} createOrderGwIcp         ICP备案码
 * @param {Function} createOrderGwRenew       续费
 * @param {Function} createOrderGwCopyright   去版权
 */
export function createOrderGwOpen(params) {
  const temp = {
    business_type: 'gw_web',
    product_id: 'basic', // 产品 ID，basic
    transaction_type: 'gw_create', // purchase
    server_line: '', // 线路 0：香港 1：大陆
    template_id: '', // 模板 ID
    host_name: '', // 主机域名
    site_name: '', // 网站名称
    keywords: '', // 关键词
    description: '', // 描述
    corp_name: ''// 企业名称
  }
  const data = Object.assign(temp, params)
  return axios.post(`${API.createOrder}`, data)
}
export function createOrderGwDomain({ business_id, amount }) {
  return axios.post(`${API.createOrder}`, {
    business_type: 'gw_web',
    transaction_type: 'gw_domain_buy',
    product_id: 'domain',
    business_id: business_id,
    amount: amount
  })
}
export function createOrderGwIcp({ business_id, amount }) {
  return axios.post(`${API.createOrder}`, {
    business_type: 'gw_web',
    transaction_type: 'gw_icp_code_buy',
    product_id: 'icp',
    business_id: business_id,
    amount: amount
  })
}
export function createOrderGwRenew({ business_id }) {
  return axios.post(`${API.createOrder}`, {
    business_type: 'gw_web',
    transaction_type: 'gw_renew',
    product_id: 'basic',
    business_id: business_id
  })
}

export function createOrderGwCopyright({ business_id }) {
  return axios.post(`${API.createOrder}`, {
    business_type: 'gw_web',
    transaction_type: 'gw_copyright',
    product_id: 'copyright',
    business_id: business_id
  })
}

/**
 * 企业邮箱
 * @param {Function} createOrderEmailBuy        购买
 * @param {Function} createOrderEmailUpgrade    升级
 * @param {Function} createOrderEmailRenew      续费
 */
export function createOrderEmailBuy(params) {
  const temp = {
    business_type: 'etp_email',
    product_id: '', // 产品 ID，basic
    transaction_type: 'email_buy' // purchase
  }
  const data = Object.assign(temp, params)
  return axios.post(`${API.createOrder}`, data)
}
export function createOrderEmailUpgrade({ product_id, business_id, amount }) {
  return axios.post(`${API.createOrder}`, {
    business_type: 'etp_email',
    transaction_type: 'email_upgrade',
    product_id: product_id,
    business_id: business_id,
    user_amount: amount
  })
}
export function createOrderEmailRenew({ product_id, business_id, years }) {
  return axios.post(`${API.createOrder}`, {
    business_type: 'etp_email',
    transaction_type: 'email_renew',
    product_id: product_id,
    business_id: business_id,
    years: years
  })
}

/**
 * 云虚拟主机
 * @param {Function} createOrderVhostBuy        购买
 * @param {Function} createOrderVhostRenew      续费
 * @param {Function} createOrderVhostUpgrade    升级
 */
export function createOrderVhostBuy(params) {
  const temp = {
    business_type: 'ny_vhost',
    product_id: '', // 产品 ID，basic
    transaction_type: 'vhost_open' // purchase
  }
  const data = Object.assign(temp, params)
  return axios.post(`${API.createOrder}`, data)
}
export function createOrderVhostRenew({ product_id, business_id, months }) {
  return axios.post(`${API.createOrder}`, {
    business_type: 'ny_vhost',
    transaction_type: 'vhost_renew',
    product_id: product_id,
    business_id: business_id,
    months: months
  })
}
export function createOrderVhostUpgrade({ product_id, business_id }) {
  return axios.post(`${API.createOrder}`, {
    business_type: 'ny_vhost',
    transaction_type: 'vhost_upgrade',
    product_id: product_id,
    business_id: business_id
  })
}

