/*
 * @Author: fengzg
 * @Date: 2020-05-11 16:14:37
 * @LastEditors: fengzg
 * @LastEditTime: 2020-05-22 14:35:15
 * @FilePath: \vue-complete\src\api\modules\common\price.js
 * @Description: 云计算API
 * @WebSite: https://www.epower.cn/
 */
import API from '../../api'
import axios from '@/utils/request' // 导入http中创建的axios实例
// import qs from 'qs' // 根据需求是否导入qs模块

/**
 * 自定义获取价格
 * @param {Function} getPrice  获取价格
 */
export function getPrice({ business_type, product_id, transaction_type }) {
  return axios.get(`${API.price}` + '/?business_type=' + business_type + '&product_id' + product_id + '&transaction_type=' + transaction_type)
}
/**
 * 官微建站
 * @param {Function} getPrice  获取价格
 * @param {Function} getPriceWebOpen  网站开通价格
 * @param {Function} getPriceWebRenew  网站续费价格
 * @param {Function} getPriceWebCopyright  网站去版权价格
 * @param {Function} getPriceWebDomain  网站购买域名数量价格
 * @param {Function} getPriceWebIcp  购买备案码价格
 */

export function getPriceWebOpen() {
  return axios.get(`${API.price}` + '?business_type=gw_web&product_id=basic&transaction_type=gw_create')
}
export function getPriceWebRenew() {
  return axios.get(`${API.price}` + '?business_type=gw_web&product_id=basic&transaction_type=gw_renew')
}
export function getPriceWebCopyright() {
  return axios.get(`${API.price}` + '?business_type=gw_web&product_id=basic&transaction_type=gw_copyright')
}
export function getPriceWebDomain(params) {
  return axios.get(`${API.price}` + '?business_type=gw_web&product_id=domain&transaction_type=gw_domain_buy&amount=' + params)
}
export function getPriceWebIcp() {
  return axios.get(`${API.price}` + '?business_type=gw_web&product_id=icp&transaction_type=gw_icp_code_buy&amount=1')
}

/**
 * 企业邮箱
 * @param {Function} getPriceEmailBuy  购买
 * @param {Function} getPriceEmailRenew  续费
 * @param {Function} getPriceEmailUpgrade  升级
 */

export function getPriceEmailBuy(user_amount, years) {
  return axios.get(`${API.price}` + '?business_type=etp_email&product_id=1&transaction_type=email_buy&user_amount=' + user_amount + '&years=' + years)
}
export function getPriceEmailRenew(product_id, business_id, months) {
  return axios.get(`${API.price}` + '?business_type=etp_email&product_id=' + product_id + '&transaction_type=email_renew&business_id' + business_id + '&months=' + months)
}
export function getPriceEmailUpgrade(product_id, business_id) {
  return axios.get(`${API.price}` + '?business_type=etp_email&product_id=' + product_id + '&transaction_type=email_upgrade&business_id' + business_id)
}
/**
 * 虚拟主机
 * @param {Function} getPriceVhostOpen  开通
 * @param {Function} getPriceVhostRenew  续费
 * @param {Function} getPriceVhostUpgrade  升级
 */

export function getPriceVhostOpen({ product_id, line_id, months }) {
  return axios.get(`${API.price}` + '?business_type=ny_vhost&product_id=' + product_id + '&transaction_type=vhost_open&line_id=' + line_id + '&months=' + months)
}
export function getPriceVhostRenew({ product_id, business_id, months }) {
  return axios.get(`${API.price}` + '?business_type=ny_vhost&product_id=' + product_id + '&transaction_type=vhost_renew&business_id=' + business_id + '&months=' + months)
}
export function getPriceVhostUpgrade({ product_id, business_id }) {
  return axios.get(`${API.price}` + '?business_type=ny_vhost&product_id=' + product_id + '&transaction_type=vhost_upgrade&business_id=' + business_id)
}
