/**
 * 商标 模块
 */
import API from '../api'
import axios from '@/utils/request' // 导入http中创建的axios实例
import qs from 'qs' // 根据需求是否导入qs模块

/**
 * 商标注册
 * @param {Function} createTmOrder 生成订单
 * @param {Function} createImage   生成图样
 * @param {Function} downloadDegationFile 下载委托书
 */
export function createImage(params) {
  return axios.post(`${API.createImage}`, qs.stringify(params))
}
export function downloadDegationFile(params) {
  return axios.post(`${API.delegationFile}`, qs.stringify(params))
}
/**
 * 商标订单
 * @param {Function} getTmOrder   商标订单列表
 * @param {Function} patchTmOrderDetail  修改商标订单
 * @param {Function} getTmOrderDetail   获取订单详情
 * @param {Function} deleteTmOrder   删除订单
 */
export function getTmOrder(params) {
  return axios.get(`${API.tmOrder}`, params)
}
export function getTmOrderDetail(id) {
  return axios.get(`${API.tmOrder}` + '/' + id)
}
export function patchTmOrderDetail(id, params) {
  return axios.put(`${API.tmOrder}` + '/' + id, params)
}
export function deleteTmOrder(id) {
  return axios.delete(`${API.tmOrder}` + '/' + id)
}

/**
 * 商标申请人
 * @param {Function} identifyImage     卡证文字识别
 * @param {Function} createApplicant   创建
 * @param {Function} editApplicant     编辑
 * @param {Function} deleteApplicant   删除
 * @param {Function} getApplicant      获取
 */

export function identifyImage(params) {
  return axios.post(`${API.characterRecognition}`, qs.stringify(params))
}
export function createApplicant(params) {
  return axios.post(`${API.applicant}`, params)
}
export function editApplicant(id, params) {
  return axios.put(`${API.applicant}` + '/' + id, qs.stringify(params))
}
export function deleteApplicant(id) {
  return axios.delete(`${API.applicant}` + '/' + id)
}
export function getApplicant(params) {
  return axios.get(`${API.applicant}`, params)
}
export function getApplicantDetail(id) {
  return axios.get(`${API.applicant}` + '/' + id)
}
/**
 * 保姆注册
 * @param {Function} getAgentList    订单列表
 * @param {Function} getAgentDetail  订单详情
 */
export function getAgentDetail(id) {
  return axios.get(`${API.tmAgentReg}` + '/' + id)
}
export function getAgentList(params) {
  return axios.get(`${API.tmAgentReg}`, qs.stringify(params))
}

/**
 * 商标服务 TODO
 * @param {Function} getTmService         服务列表
 * @param {Function} getTmPatent          专利列表
 * @param {Function} getTmCopyright       版权列表
 * @param {Function} getTmInter           国际商标列表
 * @param {Function} getUserTmServiceList     获取订单列表
 * @param {Function} getUserTmServiceDetail   获取订单详情
 * @param {Function} postUserTmService        创建服务订单
 * @param {Function} putUserTmService         修改订单
 * @param {Function} deleteUserTmService      删除订单
 */
export function getTmService() {
  return axios.get(`${API.tmService}`)
}
export function getTmPatent() {
  return axios.get(`${API.tmPatent}`)
}
export function getTmCopyright() {
  return axios.get(`${API.tmCopyright}`)
}
export function getTmInter() {
  return axios.get(`${API.tmInter}`)
}
export function getUserTmServiceList(params) {
  return axios.get(`${API.userTmService}`, params)
}
export function getUserTmServiceDetail(id) {
  return axios.get(`${API.userTmService}` + '/' + id)
}
export function postUserTmService(params) {
  return axios.post(`${API.userTmService}`, qs.stringify(params))
}
export function putUserTmService(id, params) {
  return axios.put(`${API.userTmService}` + '/' + id, qs.stringify(params))
}
export function deleteUserTmService(id) {
  return axios.delete(`${API.userTmService}` + '/' + id)
}

/**
 * 商标监控 userTmMonitor
 * @param {Function} getUserTmMonitorList     获取列表
 * @param {Function} postUserTmMonitor        创建
 * @param {Function} deleteUserTmMonitor      删除
 */
export function getUserTmMonitorList(params) {
  return axios.get(`${API.userTmMonitor}`, params)
}
export function postUserTmMonitor(params) {
  return axios.post(`${API.userTmMonitor}`, qs.stringify(params))
}
export function deleteUserTmMonitor(id) {
  return axios.delete(`${API.userTmMonitor}` + '/' + id)
}
/**
 * 商标发文列表 userTmFile
 * 索取发文 userTmFileFetch
 *
 * @param {Function} getUserTmFileList          获取商标发文列表
 * @param {Function} getUserTmFileFetchList     获取已索取发文列表
 * @param {Function} postUserTmFileFetch        创建索取发文
 * @param {Function} deleteUserTmFileFetch      删除(放弃索取发文)
 * @param {Function} getUserTmFileFetchDetail   获取已索取发文详情
 */
export function getUserTmFileList(params) {
  return axios.get(`${API.userTmFile}`, params)
}
export function getUserTmFileFetchList(params) {
  return axios.get(`${API.userTmFileFetch}`, params)
}
export function postUserTmFileFetch(params) {
  return axios.post(`${API.userTmFileFetch}`, qs.stringify(params))
}
export function deleteUserTmFileFetch(id) {
  return axios.delete(`${API.userTmFile}` + '/' + id)
}
export function getUserTmFileFetchDetail(id) {
  return axios.delete(`${API.userTmFile}` + '/' + id)
}
/**
 * 专利和版权 UserTmPatent UserTmCopyright
 *
 * @param {Function} getUserTmPatentList          获取专利列表
 * @param {Function} getUserTmCopyrightList   获取版权列表
 * @param {Function} putUserTmPatent              编辑专利
 * @param {Function} putUserTmCopyright       编辑版权
 * @param {Function} postUserTmPatent             创建专利订单
 * @param {Function} postUserTmCopyright      创建版权订单
 */
export function getUserTmPatentList(params) {
  return axios.get(`${API.userTmPatent}`, params)
}
export function getUserTmCopyrightList(params) {
  return axios.get(`${API.userTmCopyright}`, params)
}
export function putUserTmPatent(id, params) {
  return axios.put(`${API.userTmPatent}` + '/' + id, params)
}
export function putUserTmCopyright(id, params) {
  return axios.put(`${API.userTmCopyright}` + '/' + id, params)
}
export function postUserTmPatent(params) {
  return axios.post(`${API.userTmPatent}`, params)
}
export function postUserTmCopyright(params) {
  return axios.post(`${API.userTmCopyright}`, params)
}
/**
 * 国际商标 UserTmInternational
 *
 * @param {Function} getUserTmInternational        列表
 * @param {Function} postUserTmInternational       创建
 * @param {Function} deleteUserTmInternational     删除
 * @param {Function} getUserTmInternationalDetail  详情
 */
export function getUserTmInternational(params) {
  return axios.get(`${API.userTmInternational}`, params)
}
export function postUserTmInternational(params) {
  return axios.post(`${API.userTmInternational}`, qs.stringify(params))
}
export function deleteUserTmInternational(id) {
  return axios.delete(`${API.userTmInternational}` + '/' + id)
}
export function getUserTmInternationalDetail(id) {
  return axios.delete(`${API.userTmInternational}` + '/' + id)
}
/**
 * 商标交易 UserTmTransaction
 *
 * @param {Function} getUserTmTransaction        列表
 * @param {Function} postUserTmTransaction       创建
 * @param {Function} deleteUserTmTransaction     删除
 * @param {Function} getUserTmTransactionDetail  详情
 * @param {Function} patchUserTmTransaction      支付服务费和尾款
 *
 */
export function getUserTmTransaction(params) {
  return axios.get(`${API.userTmTransaction}`, params)
}
export function postUserTmTransaction(params) {
  return axios.post(`${API.userTmTransaction}`, qs.stringify(params))
}
export function deleteUserTmTransaction(id) {
  return axios.delete(`${API.userTmTransaction}` + '/' + id)
}
export function getUserTmTransactionDetail(id) {
  return axios.get(`${API.userTmTransaction}` + '/' + id)
}
export function patchUserTmTransaction(id, params) {
  return axios.patch(`${API.userTmTransaction}` + '/' + id, params)
}

/**
 * 商标发布 UserTmRelease
 *
 * @param {Function} getTmIdBatch        申请号批量查询
 * @param {Function} getUserTmRelease        列表
 * @param {Function} postUserTmRelease       创建
 * @param {Function} deleteUserTmRelease    删除
 * @param {Function} getUserTmReleaseDetail  详情
 * @param {Function} putUserTmRelease      修改
 *
 */

export function getTmIdBatch(params) {
  return axios.get(`${API.tmBatch}`, params)
}
export function getUserTmRelease(params) {
  return axios.get(`${API.userTmRelease}`, params)
}
export function postUserTmRelease(params) {
  return axios.post(`${API.userTmRelease}`, qs.stringify(params))
}
export function deleteUserTmRelease(id) {
  return axios.delete(`${API.userTmRelease}` + '/' + id)
}
export function getUserTmReleaseDetail(id) {
  return axios.get(`${API.userTmRelease}` + '/' + id)
}
export function putUserTmRelease(id, params) {
  return axios.put(`${API.userTmRelease}` + '/' + id, params)
}
/**
 * 商标持有人 UserTmHolder
 *
 * @param {Function} getUserTmHolder        列表
 * @param {Function} postUserTmHolder       创建
 * @param {Function} deleteUserTmHolder    删除
 * @param {Function} getUserTmHolderDetail  详情
 * @param {Function} putUserTmHolder      修改
 *
 */
export function getUserTmHolder(params) {
  return axios.get(`${API.userTmHolder}`, params)
}
export function postUserTmHolder(params) {
  return axios.post(`${API.userTmHolder}`, qs.stringify(params))
}
export function deleteUserTmHolder(id) {
  return axios.delete(`${API.userTmHolder}` + '/' + id)
}
export function getUserTmHolderDetail(id) {
  return axios.get(`${API.userTmHolder}` + '/' + id)
}
export function putUserTmHolder(id, params) {
  return axios.put(`${API.userTmHolder}` + '/' + id, params)
}
/**
 * 商标公证 userTmNotarization
 *
 * @param {Function} getNotarization        列表
 * @param {Function} getNotarizationDetail  详情
 * @param {Function} putNotarization      修改
 *
 */
export function getNotarization(params) {
  return axios.get(`${API.userTmNotarization}`, params)
}

export function getNotarizationDetail(id) {
  return axios.get(`${API.userTmNotarization}` + '/' + id)
}
export function putNotarization(id, params) {
  return axios.put(`${API.userTmNotarization}` + '/' + id, params)
}
/**
 * 商标查询
 * @param {Function} getTmSearch   商标查询
 * @param {Function} tmDetail     商标详情
 * @param {Function} tmCorrect   商标纠错
 * @param {Function} tmImage      图形查询
 * @param {Function} getNurseRDetail  订单详情
 * @param {Function} getTmCompany  企业查询
 * @param {Function} getTmCompanyDetail  企业查询详情
 */
export function getTmSearch(params) {
  return axios.get(`${API.tmSearch}`, params)
}
export function tmDetail(params) {
  return axios.get(`${API.tmDetail}`, params)
}
export function tmCorrect(params) {
  return axios.post(`${API.correct}`, qs.stringify(params))
}
export function tmImage(params) {
  return axios.post(`${API.tmImage}`, qs.stringify(params))
}
export function getTmCompany(params) {
  return axios.get(`${API.tmCompany}`, params)
}
export function getTmCompanyDetail(params) {
  return axios.get(`${API.tmCompanyDetail}`, params)
}
/**
 * 商标公告
 * @param {Function} tmSchedule 商标公告
 * @param {Function} tmNotice   商标查询
 */
export function tmSchedule(params) {
  return axios.get(`${API.tmSchedule}`, params)
}
export function tmNotice(params) {
  return axios.get(`${API.tmNotice}`, params)
}
/**
 * 商标分类表
 * @param {Function} getCls         商标分类
 * @param {Function} getClsDetail   分类详情
 * @param {Function} getClsSearch   分类查询
 */
export function getCls() {
  return axios.get(`${API.tmClass}`)
}
export function getClsDetail(params) {
  return axios.get(`${API.tmClassDetail}` + '/' + params)
}
export function getClsSearch(params) {
  return axios.get(`${API.tmClassSearch}` + '/' + params)
}

/**
 * 商标交易
 * @param {Function} getTmTradeCache         商标交易缓存数据
 * @param {Function} getTmTradeList          商标交易列表
 * @param {Function} getTmTradeDetail        商标交易详情
 * @param {Function} getTmTradeGroup         商标交易类似群组
 *
 */
export function getTmTradeCache() {
  return axios.get(`${API.tmTrade}` + '/cache')
}
export function getTmTradeList(params) {
  return axios.get(`${API.tmTrade}`, params)
}
export function getTmTradeDetail(params) {
  return axios.get(`${API.tmTrade}` + '/' + params)
}
export function getTmTradeGroup(params) {
  return axios.get(`${API.tmTrade}` + '/similar_group/' + params)
}
export function getTmTradeExport() {
  return axios.get(`${API.tmTradeExport}`)
}
