import { deepClone } from '../../utils'
/**
 * @params {String} 传入权限组
 * @description 通过Groups获取到具体对应的权限数组，判断当前环境是否存在于这个权限数组
 */

export default {
  install(Vue) {
    const Groups = {
      user: ['user', 'aizhan', 'chuangqibao', 'eb', 'baiyiqifu'], // user权限组
      tm: ['tm'], // tm权限组
      aizhan: ['aizhan'], // 爱站权限组
      chuangqibao: ['chuangqibao'], // 创企宝权限组
      baiyiqifu: ['baiyiqifu'], // baiyiqifu权限组
      eb: ['eb'], // eb权限组
      normal: ['user', 'tm']// 正常权限组
    }
    // 绑定到原型上，判断当前权限，组件中直接调用
    Vue.prototype.$checkPermission = function(group) {
      // 判断当前环境
      const env = process.env.VUE_APP_ENV
      const permission = Groups[group]
      if (Array.isArray(permission)) {
        return permission.indexOf(env) >= 0
      }
      return permission === env
    }
    Vue.component('view-permission', {
      props: {
        htmlTag: {
          type: String,
          default: 'span'
        },
        isInclude: {
          type: Boolean,
          default: true
        },
        verifyGroup: {
          type: String,
          default: null
        }
      },
      data() {
        return {
          /* 当前爱站为普通版，后期切换tm版，只要把user组的aizhan放到tm组即可*/
          groups: deepClone(Groups), // 权限组
          permission: null // 权限
        }
      },
      methods: {
        checkPermission() {
          const env = process.env.VUE_APP_ENV
          const permission = this.permission || this.isGroupArray()

          if (Array.isArray(permission)) {
            if (this.isInclude) {
              return permission.indexOf(env) >= 0
            } else {
              return permission.indexOf(env) === -1
            }
          }
          if (this.isInclude) {
            return permission === env
          } else {
            return permission !== env
          }
        },
        isGroupArray() {
          const array = this.verifyGroup.split(',')
          const groupsArray = []
          for (let index = 0; index < array.length; index++) {
            const v = array[index]
            if (this.groups[v]) {
              const temp = this.groups[v]
              for (let index = 0; index < temp.length; index++) {
                const v = temp[index]
                groupsArray.push(v)
              }
            }
          }
          return groupsArray
        }
      },
      render(h) {
        if (!this.verifyGroup) {
          // eslint-disable-next-line no-throw-literal
          throw 'attr \'verify-group\' is missing'
        }
        // 判断传入的权限组是否为多个
        if (this.verifyGroup.indexOf(',') !== -1) {
          // this.permission = this.isGroupArray()
        } else if (!this.groups.hasOwnProperty(this.verifyGroup)) {
          // eslint-disable-next-line no-throw-literal
          throw 'group not found: ' + this.verifyGroup
        } else {
          this.permission = this.groups[this.verifyGroup]
        }
        if (!this.permission && !this.isGroupArray()) {
          // eslint-disable-next-line no-throw-literal
          throw 'attr \'permission\' is missing'
        }
        // 如果权限对比不符合，返回空字符串
        if (!this.checkPermission()) {
          return h('')
        }
        const slots = this.$slots.default
        // 插槽没有内容 返回空字符
        if (!Array.isArray(slots) || slots.length === 0) {
          return h('')
        }

        if (slots.length === 1) {
          return slots[0]
        }
        return h(this.htmlTag, slots)
      }
    })
  }
}
