import Vue from 'vue'
import App from './App'
import store from './store'
import router from './router'
import { processRoutes } from './router'

import Vant from 'vant'
import { Lazyload } from 'vant'
import 'vant/lib/index.css'
import './styles/index.less'
import './styles/trademark.less'

import components from './components/index'
import overlay from './components/overlay.js'
import utils from './utils'

import filters from './filters' // global filters

import './permission' // permission control

import api from './api'
import link from './directive/link.js'
import { getVariables } from '@/api/modules/common'

Vue.use(Vant)
Vue.use(Lazyload, { lazyComponent: true })
Vue.use(components)
Vue.use(overlay)
Vue.use(api)
Vue.use(link)
Vue.use(utils)
Vue.use(filters)

Vue.config.productionTip = false
getVariables().then(res => {
  if (!res.configs.product.tm_query_captcha_enable || res.user !== null) {
    store.commit('layout/SET_TM_QUERY_VERIFIED', true)
  } else {
    store.commit('layout/SET_TM_QUERY_VERIFIED', res.tm_query_verified || false)
  }
  store.commit('layout/SET_TITLE_MAPS', res.seo_title_maps || null)
  store.commit('layout/SET_OPEN_INFO', res.openids || null)
  store.commit('layout/SET_CONFIGS', res.configs)
  store.commit('layout/SET_BANNERS', res.banners)
  store.commit('layout/SET_USER_INFO', res.user || null)
  processRoutes(res.routes, res.home_page_link || null)
}).finally(res => {
  new Vue({
    el: '#app',
    router,
    store,
    render: function(h) {
      return h(App)
    }
  })
})
