import Vue from 'vue'
import Router from 'vue-router'
import axios from '../utils/request2'
import CommonRoutes from './modules/common'
import UserRoutes from './modules/user'
import SinglePage from '../views/page/detail'

import TrademarkRoutes from './modules/trademark'
import TrademarkTradesRoutes from './modules/trademark-trade'
import TrademarkQueryRoutes from './modules/trademark-query'

import DomainRoutes from './modules/domain'
import CloudRoutes from './modules/cloud'
import JianzhanRoutes from './modules/jianzhan'
import XiaoChengXu from './modules/xcx'
import Ssl from './modules/ssl'
import ServiceRoutes from './modules/service'
import PatentRoutes from './modules/patent'

import UcTrademarkRoutes from './modules/uc/trademark'
import UcTrademarkTradeRoutes from './modules/uc/trademark-trade'
import UcCenter from './modules/uc/center'
import UcCenterCommon from './modules/uc/common'
import UcCenterFinance from './modules/uc/finance'
import UcCenterPromotion from './modules/uc/promotion'
import UcCenterCloud from './modules/uc/cloud'
import UcCenterJianzhan from './modules/uc/jianzhan'
import UcCenterXcx from './modules/uc/xcx'
import UcCenterDomain from './modules/uc/domain'
import UcCenterSsl from './modules/uc/ssl'
import UcCenterService from './modules/uc/service'
import UcWorkOrder from './modules/uc/work-order'
import UcShortMessage from './modules/uc/sms'
import UcPatentTrade from './modules/uc/patent'
import store from '@/store'

Vue.use(Router)

const Routes = [
  ...CommonRoutes, ...DomainRoutes, ...UserRoutes,
  ...TrademarkRoutes, ...UcTrademarkRoutes, ...UcCenter,
  ...TrademarkTradesRoutes, ...TrademarkQueryRoutes,
  ...CloudRoutes, ...JianzhanRoutes, ...ServiceRoutes,
  ...PatentRoutes,
  ...XiaoChengXu, ...Ssl, ...UcCenterCommon, ...UcCenterFinance,
  ...UcCenterPromotion, ...UcCenterCloud, ...UcCenterJianzhan,
  ...UcCenterXcx, ...UcCenterDomain, ...UcCenterSsl,
  ...UcCenterService, ...UcTrademarkTradeRoutes, ...UcWorkOrder,
  ...UcShortMessage, ...UcPatentTrade
]
const setHomePage = (homePage) => {
  if (!homePage || homePage === '/') return
  let indexRoute = null
  for (let i = 0; i < Routes.length; i++) {
    if (Routes[i].path === '/') {
      indexRoute = Routes[i]
      continue
    }
    if (Routes[i].path === homePage && indexRoute) {
      indexRoute.component = Routes[i].component
      indexRoute.name = Routes[i].name
      indexRoute.meta = Routes[i].meta
      indexRoute.meta.isHome = true
      break
    }
  }
}

const setSinglePageRoute = (pageRoutes) => {
  if (pageRoutes) {
    for (let i = 0; i < pageRoutes.length; i++) {
      Routes.push({
        path: pageRoutes[i].route,
        component: SinglePage,
        name: 'SinglePage' + pageRoutes[i].id,
        meta: {
          title: pageRoutes[i].title,
          id: pageRoutes[i].id
        }
      })
    }
  }
}

const createRouter = () =>
  new Router({
    mode: 'history', // require service support
    scrollBehavior(to, from, savedPosition) {
      if (to.meta && to.meta.keepAlive) {
        return null
      } else {
        return { x: 0, y: 0 }
      }
    },
    routes: []
  })

const router = createRouter()

export function processRoutes(pageRoutes, homePage) {
  setHomePage(homePage)
  setSinglePageRoute(pageRoutes)
  router.addRoutes(Routes)
  axios.get('tm_products?with_price=no').then(res => {
    store.commit('layout/SET_TM_PRODUCT', res.data.data)
  })
}

export default router
