import store from '../store'
import { service } from '@/api'
import { Toast } from 'vant'

export function getParam(name, url) {
  if (typeof name !== 'string') return false
  if (!url) url = window.location.href
  // 当遇到name[xx]时，对方括号做一下转义为 name\[xxx\]，因为下面还需要使用name做正则
  name = name.replace(/[\[\]]/g, '\\$&')
  var regex = new RegExp('[?&]' + name + '(=([^&#]*)|&|#|$)')
  var results = regex.exec(url)
  if (!results) return null
  if (!results[2]) return ''
  return decodeURIComponent(results[2].replace(/\+/g, ' '))
}

export function processing(message) {
  return Toast({
    message: message,
    forbidClick: true,
    position: 'top',
    duration: 0
  })
}
export function whetherShowCoupon(type) {
  const setting = store.getters.configs
  if (!setting || !setting.product) {
    return false
  }
  const coupon_enable = setting.product.coupon_enable
  const coupon_products = setting.product.coupon_products
  if (!coupon_enable) {
    return false
  }
  return coupon_products.indexOf(type) !== -1
}
export function friendlyDateTime(interval) {
  if (interval < 0) return '已结束'
  const result = []
  const day = (interval - interval % 86400) / 86400
  const hour = Math.floor(interval % 86400 / 3600)
  const minute = Math.floor(interval % 3600 / 60)
  const second = interval % 60

  if (day > 0) result.push(day + '天')
  if (hour > 0) result.push(hour + '小时')
  if (minute > 0) result.push(minute + '分')
  if (second > 0) result.push(second + '秒')
  if (result.length === 0) return ''
  if (result.length >= 2) return result[0] + result[1]
  return result[0]
}

/**
 * Parse the time to string
 * @param {(Object|string|number)} time
 * @param {string} cFormat
 * @returns {string}
 */
export function parseTime(time, cFormat) {
  if (arguments.length === 0) {
    return null
  }
  const format = cFormat || '{y}-{m}-{d} {h}:{i}:{s}'
  let date
  if (typeof time === 'object') {
    date = time
  } else {
    if ((typeof time === 'string') && (/^[0-9]+$/.test(time))) {
      time = parseInt(time)
    }
    if ((typeof time === 'number') && (time.toString().length === 10)) {
      time = time * 1000
    }
    date = new Date(time)
  }
  const formatObj = {
    y: date.getFullYear(),
    m: date.getMonth() + 1,
    d: date.getDate(),
    h: date.getHours(),
    i: date.getMinutes(),
    s: date.getSeconds(),
    a: date.getDay()
  }
  const time_str = format.replace(/{(y|m|d|h|i|s|a)+}/g, (result, key) => {
    let value = formatObj[key]
    // Note: getDay() returns 0 on Sunday
    if (key === 'a') { return ['日', '一', '二', '三', '四', '五', '六'][value] }
    if (result.length > 0 && value < 10) {
      value = '0' + value
    }
    return value || 0
  })
  return time_str
}

/**
 * @param {number} time
 * @param {string} option
 * @returns {string}
 */
export function formatTime(time, option) {
  if (('' + time).length === 10) {
    time = parseInt(time) * 1000
  } else {
    time = +time
  }
  const d = new Date(time)
  const now = Date.now()

  const diff = (now - d) / 1000

  if (diff < 30) {
    return '刚刚'
  } else if (diff < 3600) {
    // less 1 hour
    return Math.ceil(diff / 60) + '分钟前'
  } else if (diff < 3600 * 24) {
    return Math.ceil(diff / 3600) + '小时前'
  } else if (diff < 3600 * 24 * 2) {
    return '1天前'
  }
  if (option) {
    return parseTime(time, option)
  } else {
    return (
      d.getMonth() +
      1 +
      '月' +
      d.getDate() +
      '日' +
      d.getHours() +
      '时' +
      d.getMinutes() +
      '分'
    )
  }
}

/**
 * @param {string} url
 * @returns {Object}
 */
export function param2Obj(url) {
  const search = url.split('?')[1]
  if (!search) {
    return {}
  }
  return JSON.parse(
    '{"' +
    decodeURIComponent(search)
      .replace(/"/g, '\\"')
      .replace(/&/g, '","')
      .replace(/=/g, '":"')
      .replace(/\+/g, ' ') +
    '"}'
  )
}

/**
 * This is just a simple version of deep copy
 * Has a lot of edge cases bug
 * If you want to use a perfect deep copy, use lodash's _.cloneDeep
 * @param {Object} source
 * @returns {Object}
 */
export function deepClone(source) {
  if (!source && typeof source !== 'object') {
    throw new Error('error arguments', 'deepClone')
  }
  const targetObj = source.constructor === Array ? [] : {}
  Object.keys(source).forEach(keys => {
    if (source[keys] && typeof source[keys] === 'object') {
      targetObj[keys] = deepClone(source[keys])
    } else {
      targetObj[keys] = source[keys]
    }
  })
  return targetObj
}

export function text2lines(src) {
  if (!src) return []
  src = src.replace(/\r\n/g, '\n')
  src = src.replace(/\r/g, '\n')
  const items = src.split('\n')
  const length = items.length
  for (let i = length - 1; i >= 0; i--) {
    if (!items[i]) items.splice(i, 1)
  }
  return items
}
function filter(src) {
  if (!src) return src
  src = src.replace(/\r\n/g, '\n')
  src = src.replace(/\r/g, '\n')
  src = src.replace(/^\d+、/gm, '')
  src = src.replace(/^\d+\./gm, '')
  const items = src.split('\n')
  const length = items.length
  for (let i = length - 1; i >= 0; i--) {
    if (!items[i]) items.splice(i, 1)
  }
  return items
}
function parseQuestion(src) {
  if (!src) return []
  src = src.replace(/\r\n/g, '\n')
  src = src.replace(/\r/g, '\n')
  const items = src.split('\n')

  const result = []
  for (let i = 0; i < items.length; i += 2) {
    if (i + 1 >= items.length) break
    result.push({
      q: items[i],
      a: items[i + 1]
    })
  }
  return result
}
export function parseTmProduct(product) {
  if (!product.details) {
    product.details = {
      downloads: {
        files: []
      },
      files: [],
      terms: [],
      applicants: [],
      institution: [],
      notices: [],
      flows: [],
      questions: []
    }
    return product
  }
  const files = product.details.downloads.files
  const filesResult = []
  for (let i = 0; i < files.length; i++) {
    if (!files[i].tag) continue
    filesResult.push(files[i])
  }
  product.details.downloads.files = filesResult
  product.details.files = filter(product.details.files)
  product.details.terms = filter(product.details.terms)
  product.details.applicants = filter(product.details.applicants)
  product.details.institution = filter(product.details.institution)
  product.details.notices = filter(product.details.notices)
  product.details.flows = filter(product.details.flows)
  product.details.questions = parseQuestion(product.details.questions)
  return product
}

export function getBanners(type) {
  const $result = []
  const allBanners = store.getters.banners
  for (let i = 0; i < allBanners.length; i++) {
    if (allBanners[i]['type'] !== type) continue
    $result.push(allBanners[i])
  }
  return $result
}

export function canSale(identity, isOr) {
  const product = store.getters.configs['product'] || {}
  product.saleable_products = product.saleable_products || []

  if (identity instanceof Array) {
    for (let i = 0; i < identity.length; i++) {
      if (isOr === false) {
        if (product.saleable_products.indexOf(identity[i]) < 0) return false
      } else {
        if (product.saleable_products.indexOf(identity[i]) >= 0) return true
      }
    }
    return isOr === false
  }
  return product.saleable_products.indexOf(identity) >= 0
}
export function canCoupon(productType) {
  const product = store.getters.configs['product'] || {}
  if (!product.coupon_enable) return false
  const coupon_products = product.coupon_products || []

  return coupon_products.indexOf(productType) >= 0
}
/* eslint-disable */
const wxShare = (title, desc) => {
  // 做个判断，只有微信环境下且公众号登录开启的情况显示
  if (store.getters.openInfo && store.getters.openInfo["is_weixin"] && store.getters.configs.member.wx_gzh_login_enable) {
      let req = {
        jsApiList: ["onMenuShareAppMessage", "onMenuShareTimeline"],
        debug: 0, //调试模式默认关闭 0/false 是关闭
        url: location.href
      };
      service.get("/wechat/jsticket", req,{
        forbidShowMessage:true,
      }).then(res => {
        wx.config(res.data.data);
        wx.ready(function () {
          let description = desc || document.querySelectorAll('meta[name="description"]')[0].content
          let imgs = document.querySelectorAll('img')
          let imgUrl = location.origin + store.getters.configs.basic.mobile_logo
          if (imgs && imgs.length && imgs[1]) {
            imgUrl = imgs[1].src
          }
          let shareData = {
            title: title || document.title, // 分享标题
            desc: description, // 分享描述
            link: location.href, // 分享链接，该链接域名或路径必须与当前页面对应的公众号JS安全域名一致
            imgUrl: imgUrl // 分享图标
          }
          // 需在用户可能点击分享按钮前就先调用
          wx.onMenuShareAppMessage(shareData)
          // 需在用户可能点击分享按钮前就先调用
          wx.onMenuShareTimeline(shareData)
        });
      });
  }
}
export function setTitle(title, description) {
  const basic = store.getters.configs['basic'] || {}
  // title 不存在
  if (!title) {
    document.title = basic['site_name']
    wxShare(title, description)
    return
  }
  // title 不等于 网站名称且不以网站名称结尾，尾部加上网站名称
  if (title !== basic['site_name'] && !title.endsWith(' - ' + basic['site_name'])) {
    document.title = title + ' - ' + basic['site_name']
  } else {
    document.title = title
  }
  wxShare(title, description)
}

export function CallAff() {
  const el = document.querySelector('ins.nb-icon-wrap-base')
  if (!el) return;
  el.click();
}
export function lazyFunction(fn, timeout){
  let timer = 0;
  return function(){
    if(timer) window.clearTimeout(timer);
    let args = arguments, that = this;
    timer = window.setTimeout(function(){
      fn.apply(that, args)
    }, timeout);
  };
}

export function debounceFunction(fn, timeout) {
  return lazyFunction(fn, timeout)
}

export function objectTextValued(source, inserted) {
  const temp = []
  for (const key in source) {
    if (!source.hasOwnProperty(key)) continue;
      temp.push({
        text: source[key],
        value: key
      })
  }
  if(inserted){
    temp.unshift(inserted)
  }
  return temp;
}


export default {
  install(Vue){

    Vue.prototype.deepClone = deepClone
    Vue.prototype.friendlyDateTime = friendlyDateTime
    Vue.prototype.whetherShowCoupon = whetherShowCoupon

    Vue.prototype.processing = processing
    Vue.prototype.getParam = getParam
  }
}
