import { IQuery } from './iquery'

const cnames = {
  domainstatus: 'status',
  roid: 'domainid',
  sponsoringregistrar: 'registrar',
  registrationtime: 'creationdate',
  expirationtime: 'expirationdate',
  registryexpirydate: 'expirationdate',
  registrant: 'registrantname',
  registrantcontactemail: 'registrantemail'
}
const maps = {
  domainname: '域名',
  status: '状态',
  whoisserver: 'WHOIS服务器',
  referralurl: '注册商网址',
  registrar: '注册商',
  nameserver: 'DNS服务器',
  creationdate: '注册日期',
  expirationdate: '到期日期',
  updateddate: '更新日期',
  registrantid: '所有者ID',
  registrantname: '所有者',
  registrantemail: '所有者邮箱'
}

const monthes = {
  jan: '01',
  feb: '02',
  mar: '03',
  apr: '04',
  may: '05',
  jun: '06',
  jul: '07',
  aug: '08',
  sep: '09',
  sept: '09',
  oct: 10,
  nov: 11,
  dec: 12
}

// 日期格式化
function datetimeFilter(datetime) {
  if (!datetime) {
    return ''
  }
  let match = null
  match = /^(\d+)\-([a-z]+)\-(\d+)$/i.exec(datetime)
  if (match) {
    return [match[3], monthes[match[2].toLowerCase()], match[1]].join('-')
  }
  match = /^(.+?)T(.+?)Z$/i.exec(datetime)
  if (match) {
    return match[1] + ' ' + match[2]
  }
  return datetime
}

// /属性过滤，显示为中文
function attrFilter(name, eng) {
  name = name.replace(/\s/g, '').toLowerCase()
  if (eng === true) {
    return cnames[name] || name
  }
  return maps[cnames[name] || name]
}
function isEmail(value) {
  if (/^([\w\.\-]+)@([\w\.\-]+)\.(\w+)$/.test(value)) return value
  return '已开启隐私保护'
}
// /格式化WHOIS信息
function formatWhois(whois) {
  const result = IQuery(whois.replace(/\r\n/g, '\n').replace(/\r/g, '\n').replace(/\n\n/g, '\n').split('\n'))
    .where(function(t) {
      return t !== '' && t.indexOf(': ') > 0
    })
    .select(function(t) {
      const index = t.indexOf(':')
      let name = t.substr(0, index).trim()
      let value = t.substr(index + 1).trim()
      name = attrFilter(name, true)
      if (name === undefined) return null
      if (name === 'creationdate' || name === 'expirationdate' || name === 'updateddate') {
        value = datetimeFilter(value)
      }
      return [name, value]
    }).where(function(t) {
      return t != null
    }).toArray()
  const retValue = {}
  let item = null
  let name
  let value
  let lists

  for (let i = 0; i < result.length; i++) {
    item = result[i]
    name = item[0]
    value = item[1]
    if (!retValue.hasOwnProperty(name)) {
      if (name === 'nameserver' || name === 'status') {
        retValue[name] = []
      } else {
        if (name === 'registrantemail') {
          value = isEmail(value)
        }
        retValue[name] = value
        continue
      }
    }
    if (name === 'nameserver' || name === 'status') {
      lists = retValue[name]
      let find = false
      if (name === 'status') {
        const idx = value.indexOf(' ')
        if (idx > 0) {
          value = value.substr(0, idx)
        }
      }
      for (let j = 0; j < lists.length; j++) {
        if (lists[j].toLowerCase() === value.toLowerCase()) {
          find = true
          break
        }
      }
      if (find) {
        continue
      }
      lists.push(value)
    }
  }
  return retValue
}

// /清理几个后缀的WHOIS详情
function filterCOM(whois) {
  let index = whois.indexOf('Domain Name:')
  if (index < 0) {
    return whois
  }
  whois = whois.substr(index)
  index = whois.indexOf('&gt;&gt;&gt')
  if (index <= 0) {
    return whois
  }
  return whois.substr(0, index)
}
// /查询WHOIS
export function getWhois(domain, content) {
  const _whois = content
  let whois = _whois
  const out = { domain: domain, detail: _whois, isCOM: false }
  const ext = domain.substr(domain.indexOf('.')).toLowerCase()
  if (ext === '.com' || ext === '.net' || ext === '.cc' || ext === '.org' || ext === '.tv') {
    whois = filterCOM(whois)
    out.isCOM = true
    out.filterWhois = whois
  }
  out.result = formatWhois(whois)
  return out
}
