/*
 * @Author: fengzg
 * @Date: 2020-05-11 16:14:37
 * @LastEditors: fengzg
 * @LastEditTime: 2020-09-01 12:12:55
 * @FilePath: \vue-center\src\api\modules\cloud.js
 * @Description: 云计算API
 * @WebSite: https://www.epower.cn/
 */
import axios from '@/utils/request' // 导入http中创建的axios实例
import qs from 'qs' // 根据需求是否导入qs模块
const API = {
  serversLines: '/server_lines', // 线路信息
  packages: '/vhosts/packages', // 套餐信息
  servers: '/user/servers', // 云服务器
  serversSnapshots: '/user/snapshots', // 云服务器快照
  vhosts: '/user/vhosts', // 云虚拟主机
  vhostDbs: '/user/vhost_dbs', // 云虚拟主机数据库
  vhostsPackages: '/vhost/packages' // 虚机套餐
}
/**
 * 服务器操作
 * @param {Function} getServerList  获取服务器列表
 * @param {Function} getServerSnapshotsList  获取快照列表
 * @param {Function} putServerHandle  云服务器重装系统(reinstall)、启动(start)、关机(shutdown)、重启(restart)、锁定(lock)、解锁(unlock)、重置密码(pwd_set)
 * @param {Function} putSnapshotsHandle  云服务器快照还原(revert)、删除(remove)
 */
export const getServerLines = () => {
  return axios.get(API.serversLines)
}
export function getServerList(params) {
  return axios.get(API.servers + '?' + qs.stringify(params))
}
export function getServerSnapshotsList(id) {
  return axios.get(API.servers + '/' + id + '/snapshots')
}
export function putServerHandle({ type, id, params }) {
  return axios.put(API.servers + '/' + id + '/' + type, qs.stringify(params))
}
export function putSnapshotsHandle({ type, id, params }) {
  return axios.put(API.servers + '/' + id + '/' + type, qs.stringify(params))
}
export function getServerDetail(id) {
  return axios.get(API.servers + '/' + id)
}
export function getServerMnage(id) {
  return axios.get('/user/servers/' + id + '/manage')
}

/**
 * 虚拟主机
 * @param {Function} getHostList  获取虚拟主机列表
 * @param {Function} putHostHandle  云虚拟主机重装系统(reinstall)、启动(start)、关机(shutdown)、重启(restart)、锁定(lock)、解锁(unlock)、重置密码(pwd_set)
 * @param {Function} putSnapshotsHandle  云虚拟主机快照还原(revert)、删除(remove)
 */
export function getHostList(params) {
  return axios.get(API.vhosts + '?' + qs.stringify(params))
}
export function getHostDetail(id) {
  return axios.get(API.vhosts + '/' + id)
}
export function getHostMnage(id) {
  return axios.get('/user/vhosts/' + id + '/manage')
}

/**
 * @description: 虚机操作
 * @param { id, type, handle, params} ：虚机ID，请求类型，操作类型，参数
 * @return: Function
 */
export function hostHandle({ id, ajaxType, handle, params }) {
  let returnFunction = {}
  switch (ajaxType) {
    case 'delete':
      // 云虚拟主机域名解绑 特殊处理  /admin/vhosts/domains/:domain
      if (handle === 'domains') {
        returnFunction = axios.delete(
          API.vhosts + '/' + handle + '/' + id,
          qs.stringify(params)
        )
      } else {
        returnFunction = axios.delete(
          API.vhosts + '/' + id + '/' + handle,
          qs.stringify(params)
        )
      }
      break
    default:
      returnFunction = axios.put(
        API.vhosts + '/' + id + '/' + handle,
        qs.stringify(params)
      )
      break
  }
  return returnFunction
}

/**
 * 虚拟主机数据库
 * @param {Function} dbOpen  获取虚拟主机列表
 * @param {Function} dbList
 * @param {Function} dbClear
 */

export function dbOpen(id, params) {
  return axios.post(API.vhosts + '/' + id, qs.stringify(params))
}

export function dbList() {
  return axios.get(API.vhostDbs)
}

export function dbHandle({ id, handle, params }) {
  let returnFunction = {}
  returnFunction = axios.put(
    API.vhostDbs + '/' + id + '/' + handle,
    qs.stringify(params)
  )
  return returnFunction
}

export const getPackage = () => {
  return axios.get(API.packages)
}
