/*
 * @Author: fengzg
 * @Date: 2020-01-14 15:35:08
 * @LastEditors: fengzg
 * @LastEditTime: 2020-09-11 11:47:55
 * @FilePath: \vue-center\src\api\modules\common.js
 * @Description: 通用模块
 * @WebSite: https://www.epower.cn/
 */

import axios from '@/utils/request' // 导入http中创建的axios实例
import qs from 'qs' // 根据需求是否导入qs模块
const API = {
  token: '/authorizations', // 获取token
  tokenInfo: '/authorizations/current', // token操作
  userInfo: '/user/users/current', // 根据token 获取用户信息
  navigations: '/navigations', // 获取导航
  customer: '/customer_service_staffs', // 客服
  setting: '/settings', // 获取基本信息
  verifyCode: '/captcha', // 验证弹窗图形验证码  mobile:''  captcha:''
  smsCode: '/sms', // 短信验证码
  email: '/email', // 邮件验证码
  createOrder: '/user/payment/order', // 生成订单
  payOrder: '/user/payment/pay', // 支付订单
  price: '/price',
  wechat: '/wechat/qr_code'
}
/**
 * 获取系统设置
 * @param {Function} getSetting  获取基本配置
 */
export function getSetting(params) {
  return axios.get(API.setting, params)
}
export const getNotices = (params) => {
  return axios.get('/articles?category=tm_ipr&class=announcement', { params })
}
/**
 * token 登录
 * @param {Function} getServerToken 获取服务端token
 * @param {Function} removeServerToken   删除token
 */

export function getServerToken(params) {
  return axios.post(API.token, qs.stringify(params))
}
export function removeServerToken(params) {
  return axios.delete(API.tokenInfo, qs.stringify(params))
}

/**
 * 修改用户信息
 * @param {Function} getInfo   获取用户信息
 */
export function getInfo() {
  return axios.get(API.userInfo)
}

/**
 * @param {Function} postWechatCode   获取微信二维码
 * @param {Function} getWechatCode    验证扫码结果
 */
export function postWechatCode() {
  return axios.post(API.wechat)
}
export function getWechatCode(params) {
  return axios.get(API.wechat + '?flag=' + params)
}

/**
 * @param {Function} getCustomer  客服列表
 */
export function getCustomer() {
  return axios.get(API.customer)
}

/**
 * @param {Function} getNavigations  获取顶部导航\底部导航
 */

export function getNavigations() {
  return axios.get(API.navigations)
}

/**
 * @param {Function} getCoupons 获取优惠券列表
 */
export function getCoupons() {
  return axios.get(API.coupons)
}

/**
 * @param {Function} getCode 获取图形验证码
 * @param {Function} verifyCode 验证图形验证码
 * @param {Function} getEmailCode 邮件验证码
 * @param {Function} verifyEmail 验证邮件验证码
 * @param {Function} getSms 获取短信验证码
 * @param {Function} verifySms 验证短信验证码
 */
export function getCode() {
  return axios.post(API.verifyCode)
}
export function verifyCode(params) {
  return axios.get(API.verifyCode, params)
}
export function getSms(params) {
  return axios.post(API.smsCode, qs.stringify(params))
}
export function verifySms(params) {
  return axios.get(API.smsCode, params)
}

export function getEmailCode(params) {
  return axios.post(API.email, qs.stringify(params))
}

export function verifyEmail(params) {
  return axios.get(API.email, params)
}

/**
 * @description: 创建订单
 * @param {Function} createOrder 创建订单
 * @param {Function} payOrder 支付订单
 */
export function createOrder(params) {
  return axios.post(API.createOrder, qs.stringify(params))
}
export function payOrder(params) {
  return axios.post(API.payOrder, qs.stringify(params))
}

/**
 * 自定义获取价格
 * @param {Function} getPrice  获取价格
 */
export function getPrice(params) {
  return axios.get(API.price + '?' + qs.stringify(params))
}

export function loadJsonData($url) {
  return axios.get($url, { baseURL: '/', responseType: 'json' })
}
export function address() {
  return axios.get(API.resources.address, {
    baseURL: '/',
    responseType: 'json'
  })
}
const require_cache = {}

function parseResponse(data, $config) {
  const module = { exports: {}}
  new Function('module', 'exports', data)(module, module.exports)
  if ($config && $config.flat === true) {
    const idName = $config['id'] || 'id'
    const parentIdName = $config['parent_id'] || 'parent_id'
    const data = module.exports
    if (!(data instanceof Array)) return module.exports

    const result = { maps: {}, datas: {}}
    let item = null
    let parent_id

    const maps = result.maps
    const datas = result.datas
    for (let i = 0; i < data.length; i++) {
      item = data[i]
      parent_id = item[parentIdName]
      datas[item[idName]] = item
      if (!maps.hasOwnProperty(parent_id)) {
        maps[parent_id] = []
      }
      maps[parent_id].push(item)
    }
    return result
  }
  return module.exports
}
export function require($url, $config) {
  if (require_cache.hasOwnProperty($url)) {
    return new Promise((resolve, reject) => {
      resolve(parseResponse(require_cache[$url], $config))
    })
  }
  return axios
    .get($url, {
      baseURL: '/',
      responseType: 'text',
      validateStatus: statusCode => true,
      ignoreInterceptors: true
    })
    .then(function(response) {
      if (response.status >= 400 || !response.data) return null
      require_cache[$url] = response.data
      return parseResponse(response.data, $config)
    })
}

export function getVariables(scope) {
  return axios.get('/platform_variables', { baseURL: '/', params: { vars: scope || 'version,navigations' }})
}
