/*
 * @Author: fengzg
 * @Date: 2020-06-10 18:46:25
 * @LastEditors: fengzg
 * @LastEditTime: 2020-09-10 16:51:22
 * @FilePath: \vue-center\src\api\modules\domain.js
 * @Description:
 * @WebSite: https://www.epower.cn/
 */
import axios from '@/utils/request' // 导入http中创建的axios实例
// import qs from 'qs' // 根据需求是否导入qs模块

const API = {
  domainPrice: '/domain/get_price', // 域名价格
  domainTemplate: '/user/domain_template', // 域名模板
  domainList: '/user/domain', // 域名列表
  domainOut: '/user/domain_transfer_out', // 域名转出
  domainIn: '/user/domain_transfer_in', // 域名转入
  domainPush: '/user/domain_push', // 域名push
  domainSuffix: '/domain/get_list_info', // 域名后缀
  whois: '/domain/whois',
  domain_trades: '/user/domain_trades',
  checkDomain: '/user/domain_trades/domain/check' // 域名检测
}

/**
 * 域名模板
 * @param {Function} getTemplate            获取模板列表
 * @param {Function} deleteTemplate         删除模板
 * @param {Function} getTemplateDetail      域名模板详情
 * @param {Function} postTemplate           创建模板
 * @param {Function} putTemplate            修改模板
 *
 * 域名注册
 * @param {Function} getList                域名列表
 * @param {Function} getNormalList          我的正常域名
 * @param {Function} getDetail              域名详情
 * @param {Function} getManageAuth          管理授权
 * @param {Function} getChangeTemplate      获取过户模板
 * @param {Function} putChangeTemplate      更换域名模板（过户）
 *
 * 域名转出
 * @param {Function} getTransferOut         域名转出列表
 * @param {Function} postTransferOut        创建域名转出
 *
 * 域名转入
 * @param {Function} getTransferIn          域名转入列表
 * @param {Function} postTransferIn         创建域名转入
 *
 * 域名push
 * @param {Function} getPush                域名push列表
 * @param {Function} getReceivePush   域名push接收列表
 * @param {Function} postPush               创建域名push
 * @param {Function} putPush                取消域名push
 * @param {Function} putReceivePush   接收域名push
 *
 * 获取域名价格
 * @param {Function} getPrice               域名转出列表
 *
 * whois查询
 * @param {Function} getWhois               域名转出列表
 *
 */
export const checkDomain = (params) => {
  return axios.post(API.checkDomain, params)
}
export const publishDomain = (params) => {
  return axios.post(API.domain_trades, params)
}

export function getTemplate(params) {
  return axios.get(API.domainTemplate, params)
}
export function deleteTemplate(id) {
  return axios.get(API.domainTemplate + '/' + id)
}
export function getTemplateDetail(id) {
  return axios.get(API.domainTemplate + '/' + id)
}
export function getSuffix(params) {
  return axios.get(API.domainSuffix, params)
}
export function postTemplate(params) {
  return axios.post(API.domainTemplate, params)
}
export function postDefaultTemplate(id, params) {
  return axios.post(API.domainTemplate + '/set_default/' + id, params)
}
export function putTemplate(id, params) {
  return axios.put(API.domainTemplate + '/' + id, params)
}

export function getList(params) {
  return axios.get(API.domainList, params)
}
export function getNormalList(params) {
  return axios.get(API.domainList + '/normal_Domain', params)
}
export function getDetail(id) {
  return axios.get(API.domainList + '/' + id)
}

export function getManageAuth(id) {
  return axios.get(API.domainList + '/manage_auth/' + id)
}
export function getChangeTemplate(id) {
  return axios.get(API.domainList + '/get_change_template/' + id)
}

export function putChangeTemplate(id, params) {
  return axios.get(API.domainList + '/change_template/' + id, params)
}

export function getTransferOut(params) {
  return axios.get(API.domainOut, params)
}
export function postTransferOut(params) {
  return axios.post(API.domainOut, params)
}

export function getTransferIn(params) {
  return axios.get(API.domainIn, params)
}

export function postTransferIn(params) {
  return axios.get(API.domainIn, params)
}

export function getPush(params) {
  return axios.get(API.domainPush, params)
}
export function getReceivePush(params) {
  return axios.get(API.domainPush + '/receive', params)
}
export function postPush(params) {
  return axios.get(API.domainPush, params)
}
export function putPush(params) {
  return axios.get(API.domainPush, params)
}
export function putReceivePush(params) {
  return axios.get(API.domainPush, params)
}

/**
 * @param {Function} getPrice       获取域名价格
 *
 */

export function getPrice(params) {
  return axios.get(API.domainPrice, params)
}

export function getWhois(params) {
  return axios.post(API.whois, params)
}

