/**
 * 商标 模块
 */
import axios from '@/utils/request' // 导入http中创建的axios实例
import qs from 'qs' // 根据需求是否导入qs模块
const API = {
  tmOrder: '/user/tm_reg', // 商标注册订单
  tempOrder: '/user/tm_reg_temp', // 商标临时订单
  userTmService: '/user/tm_service', // 商标服务
  userTmPatent: '/user/tm_patent', // 商标专利
  userTmCopyright: '/user/tm_copyright', // 商标专利
  userTmInternational: '/user/tm_international', // 国际商标
  userTmFile: '/user/tm_file', // 发文列表
  userTmFileFetch: '/user/tm_file', // 发文索取
  userTmMonitor: '/user/tm_monitor', // 商标监控
  userTmTransaction: '/user/tm_trade', // 商标交易
  userTmRelease: '/user/tm_trade_local_lib', // 商标发布
  userTmHolder: '/user/tm_trade_holder', // 交易持有人
  userTmNotarization: '/user/tm_notarization', // 商标公证
  applicant: '/user/tm_applicant', // 申请人
  characterRecognition: '/user/character_recognition', // 卡证文字识别
  tmForm: '/user/tm_registration', // 商标注册
  tmAgentReg: '/user/tm_agent_reg', // 保姆注册
  tempAgent: '/user/tm_agent_reg_temp',
  tmService: '/tm_service', // 商标服务列表
  tmPatent: '/tm_patent', // 专利列表
  tmCopyright: '/tm_copyright', // 版权列表
  tmInter: '/tm_international', // 国际商标
  tmTrade: '/tm_trade', // 商标交易
  tmBatch: '/tm/tmids_list_search' // 商标申请号批量查询
}
/**
 * 商标订单
 * @param {Function} getTmOrder   商标订单列表
 * @param {Function} patchTmOrderDetail  修改商标订单
 * @param {Function} getTmOrderDetail   获取订单详情
 * @param {Function} deleteTmOrder   删除订单
 */
export function getTmOrder(params) {
  return axios.get(API.tmOrder, params)
}
export function getTmOrderDetail(id) {
  return axios.get(API.tmOrder + '/' + id)
}
export function patchTmOrderDetail(id, params) {
  return axios.put(API.tmOrder + '/' + id, params)
}
export function deleteTmOrder(id) {
  return axios.delete(API.tmOrder + '/' + id)
}
export function getTmRegTemp(params) {
  return axios.get(API.tempOrder, params)
}
export function deleteTmOrderTemp(id) {
  return axios.delete(API.tempOrder + '/' + id)
}
/**
 * 商标申请人
 * @param {Function} identifyImage     卡证文字识别
 * @param {Function} createApplicant   创建
 * @param {Function} editApplicant     编辑
 * @param {Function} deleteApplicant   删除
 * @param {Function} getApplicant      获取
 */

export function identifyImage(params) {
  return axios.post(API.characterRecognition, qs.stringify(params))
}
export function createApplicant(params) {
  return axios.post(API.applicant, params)
}
export function editApplicant(id, params) {
  return axios.put(API.applicant + '/' + id, qs.stringify(params))
}
export function deleteApplicant(id) {
  return axios.delete(API.applicant + '/' + id)
}
export function getApplicant(params) {
  return axios.get(API.applicant, params)
}
export function getApplicantDetail(id) {
  return axios.get(API.applicant + '/' + id)
}
/**
 * 保姆注册
 * @param {Function} getAgentList    订单列表
 * @param {Function} getAgentDetail  订单详情
 */
export function getAgentDetail(id) {
  return axios.get(API.tmAgentReg + '/' + id)
}

export function getAgentList(params) {
  return axios.get(API.tmAgentReg, params)
}
export function getTmAgentTemp(params) {
  return axios.get(API.tempAgent, params)
}
export function getAgentDetailTemp(id) {
  return axios.get(API.tempAgent + '/' + id)
}
export function putTmAgentTemp(id, params) {
  return axios.put(API.tempAgent + '/' + id, params)
}
export function deleteTmAgentTemp(id) {
  return axios.delete(API.tempAgent + '/' + id)
}

/**
 * 商标服务
 * @param {Function} getTmService         服务列表
 * @param {Function} getTmPatent          专利列表
 * @param {Function} getTmCopyright       版权列表
 * @param {Function} getTmInter           国际商标列表
 * @param {Function} getTmServiceList     获取订单列表
 * @param {Function} getTmServiceDetail   获取订单详情
 * @param {Function} postTmService        创建服务订单
 * @param {Function} putTmService         修改订单
 * @param {Function} deleteTmService      删除订单
 */
export function getTmServiceTemp(params) {
  return axios.get(API.userTmService + '_temp', params)
}
export function getTmServiceTempDetail(id) {
  return axios.get(API.userTmService + '_temp' + '/' + id)
}
export function deleteTmServiceTemp(id) {
  return axios.delete(API.userTmService + '_temp' + '/' + id)
}

export function putTmServiceTemp(id, params) {
  return axios.put(API.userTmService + '_temp' + '/' + id, qs.stringify(params))
}

export function getTmService(params) {
  return axios.get(API.tmService, params)
}

export function getTmPatent() {
  return axios.get(API.tmPatent)
}
export function getTmCopyright() {
  return axios.get(API.tmCopyright)
}
export function getTmInter() {
  return axios.get(API.tmInter)
}
export function getTmServiceList(params) {
  return axios.get(API.userTmService, params)
}
export function getTmServiceDetail(id) {
  return axios.get(API.userTmService + '/' + id)
}
export function postTmService(params) {
  return axios.post(API.userTmService, qs.stringify(params))
}
export function putTmService(id, params) {
  return axios.put(API.userTmService + '/' + id, qs.stringify(params))
}
export function deleteTmService(id) {
  return axios.delete(API.userTmService + '/' + id)
}

/**
 * 商标监控 userTmMonitor
 * @param {Function} getTmMonitorList     获取列表
 * @param {Function} postTmMonitor        创建
 * @param {Function} deleteTmMonitor      删除
 */
export function getTmMonitorList(params) {
  return axios.get(API.userTmMonitor, params)
}
export function postTmMonitor(params) {
  return axios.post(API.userTmMonitor, qs.stringify(params))
}
export function deleteTmMonitor(id) {
  return axios.delete(API.userTmMonitor + '/' + id)
}
/**
 * 商标发文列表 userTmFile
 * 索取发文 userTmFileFetch
 *
 * @param {Function} getTmFileList          获取商标发文列表
 * @param {Function} getTmFileFetchList     获取已索取发文列表
 * @param {Function} postTmFileFetch        创建索取发文
 * @param {Function} deleteTmFileFetch      删除(放弃索取发文)
 * @param {Function} getTmFileFetchDetail   获取已索取发文详情
 */
export function getTmFileList(params) {
  return axios.get(API.userTmFile, params)
}
export function getTmFileFetchList(params) {
  return axios.get(API.userTmFileFetch, params)
}
export function postTmFileFetch(params) {
  return axios.post(API.userTmFileFetch, qs.stringify(params))
}
export function deleteTmFileFetch(id) {
  return axios.delete(API.userTmFile + '/' + id)
}
export function getTmFileFetchDetail(id) {
  return axios.delete(API.userTmFile + '/' + id)
}
/**
 * 专利和版权 TmPatent TmCopyright
 *
 * @param {Function} getTmPatentList          获取专利列表
 * @param {Function} getTmCopyrightList   获取版权列表
 * @param {Function} putTmPatent              编辑专利
 * @param {Function} putTmCopyright       编辑版权
 * @param {Function} postTmPatent             创建专利订单
 * @param {Function} postTmCopyright      创建版权订单
 */
export function getTmPatentList(params) {
  return axios.get(API.userTmPatent, params)
}

export function getTmCopyrightList(params) {
  return axios.get(API.userTmCopyright, params)
}
export function putTmPatent(id, params) {
  return axios.put(API.userTmPatent + '/' + id, params)
}
export function putTmCopyright(id, params) {
  return axios.put(API.userTmCopyright + '/' + id, params)
}
export function postTmPatent(params) {
  return axios.post(API.userTmPatent, params)
}
export function postTmCopyright(params) {
  return axios.post(API.userTmCopyright, params)
}
/**
 * 国际商标 TmInternational
 *
 * @param {Function} getTmInternational        列表
 * @param {Function} postTmInternational       创建
 * @param {Function} deleteTmInternational     删除
 * @param {Function} getTmInternationalDetail  详情
 */
export function getTmInternational(params) {
  return axios.get(API.userTmInternational, params)
}
export function postTmInternational(params) {
  return axios.post(API.userTmInternational, qs.stringify(params))
}
export function deleteTmInternational(id) {
  return axios.delete(API.userTmInternational + '/' + id)
}
export function getTmInternationalDetail(id) {
  return axios.delete(API.userTmInternational + '/' + id)
}
/**
 * 商标交易 TmTransaction
 *
 * @param {Function} getTmTransaction        列表
 * @param {Function} postTmTransaction       创建
 * @param {Function} deleteTmTransaction     删除
 * @param {Function} getTmTransactionDetail  详情
 * @param {Function} patchTmTransaction      支付服务费和尾款
 *
 */
export function getTmTransaction(params) {
  return axios.get(API.userTmTransaction, params)
}
export function postTmTransaction(params) {
  return axios.post(API.userTmTransaction, qs.stringify(params))
}
export function deleteTmTransaction(id) {
  return axios.delete(API.userTmTransaction + '/' + id)
}
export function getTmTransactionDetail(id) {
  return axios.get(API.userTmTransaction + '/' + id)
}
export function patchTmTransaction(id, params) {
  return axios.patch(API.userTmTransaction + '/' + id, params)
}
/**
 * 商标发布 TmRelease
 *
 * @param {Function} getTmIdBatch        申请号批量查询
 * @param {Function} getTmRelease        列表
 * @param {Function} postTmRelease       创建
 * @param {Function} deleteTmRelease    删除
 * @param {Function} getTmReleaseDetail  详情
 * @param {Function} putTmRelease      修改
 *
 */

export function getTmIdBatch(params) {
  return axios.get(API.tmBatch, params)
}
export function getTmRelease(params) {
  return axios.get(API.userTmRelease, params)
}
export function postTmRelease(params) {
  return axios.post(API.userTmRelease, qs.stringify(params))
}
export function deleteTmRelease(id) {
  return axios.delete(API.userTmRelease + '/' + id)
}
export function getTmReleaseDetail(id) {
  return axios.get(API.userTmRelease + '/' + id)
}
export function putTmRelease(id, params) {
  return axios.put(API.userTmRelease + '/' + id, params)
}
/**
 * 商标持有人 TmHolder
 *
 * @param {Function} getTmHolder        列表
 * @param {Function} postTmHolder       创建
 * @param {Function} deleteTmHolder    删除
 * @param {Function} getTmHolderDetail  详情
 * @param {Function} putTmHolder      修改
 *
 */
export function getTmHolder(params) {
  return axios.get(API.userTmHolder, params)
}
export function postTmHolder(params) {
  return axios.post(API.userTmHolder, qs.stringify(params))
}
export function deleteTmHolder(id) {
  return axios.delete(API.userTmHolder + '/' + id)
}
export function getTmHolderDetail(id) {
  return axios.get(API.userTmHolder + '/' + id)
}
export function putTmHolder(id, params) {
  return axios.put(API.userTmHolder + '/' + id, params)
}
/**
 * 商标公证 userTmNotarization
 *
 * @param {Function} getNotarization        列表
 * @param {Function} getNotarizationDetail  详情
 * @param {Function} putNotarization      修改
 *
 */
export function getNotarizationTemp(params) {
  return axios.get('/user/tm_notarization_temp', params)
}
export function getNotarization(params) {
  return axios.get(API.userTmNotarization, params)
}

export function getNotarizationDetail(id) {
  return axios.get(API.userTmNotarization + '/' + id)
}
export function putNotarization(id, params) {
  return axios.put(API.userTmNotarization + '/' + id, params)
}
/**
 * 商标交易
 * @param {Function} getTmTradeCache         商标交易缓存数据
 * @param {Function} getTmTradeList          商标交易列表
 * @param {Function} getTmTradeDetail        商标交易详情
 * @param {Function} getTmTradeGroup         商标交易类似群组
 *
 */
export function getTmTradeCache() {
  return axios.get(API.tmTrade + '/cache')
}
export function getTmTradeList(params) {
  return axios.get(API.tmTrade, params)
}
export function getTmTradeDetail(params) {
  return axios.get(API.tmTrade + '/' + params)
}
export function getTmTradeGroup(params) {
  return axios.get(API.tmTrade + '/similar_group/' + params)
}
