import router from './router'
import store from './store'
import { Message } from 'element-ui'
import NProgress from 'nprogress' // progress bar

NProgress.configure({ showSpinner: false }) // NProgress Configuration

const resolvers = {
  'TmNormalOrder': () => { return store.getters.PRODUCTS_ZHUCE },
  'TmNormalOrderDetail': () => { return store.getters.PRODUCTS_ZHUCE + '订单' },
  'TmAgentOrder': () => { return store.getters.PRODUCTS_ZHUCEBM }
}

const setTitle = (route) => {
  if (resolvers.hasOwnProperty(route.name)) {
    const title = resolvers[route.name]()
    document.title = title + ' - ' + store.getters.setting.basic.site_name
    if (!route.meta.titled) {
      route.meta.title = title
      route.meta.titled = true
    }
  } else {
    if (route.meta.title) {
      document.title = route.meta.title + ' - ' + store.getters.setting.basic.site_name
    } else {
      document.title = '用户中心' + ' - ' + store.getters.setting.basic.site_name
    }
  }
}

// 路由钩子函数 跳转前执行
router.beforeEach(async(to, from, next) => {
  NProgress.start()
  if (store.getters.setting.basic) {
    setTitle(to)
  }
  // 如果token存在
  if (store.getters.userInfo) {
    next()
  } else {
    /* has no token*/
    // 这里可以做一个登录限制
    if (process.env.NODE_ENV === 'production') {
      location.href = '/login'
    } else if (to.name !== 'Login') {
      Message.warning('开发环境查看用户中心需要登录！')
      next(`/userLogin?redirect=${to.path}`)
    } else {
      // 如果没有登录直接跳转前台登录页面
      next()
    }
  }
  NProgress.done()
})
