/**
 * 基本信息
 */
import { require } from '@/api/modules/common'
import { deepClone } from '@/utils'

const state = {
  setting: {}, // 全局设置
  classData: [], // 分类数据
  classMap: {},
  topMenu: [],
  PRODUCTS_ZHUCE: '自助注册',
  PRODUCTS_ZHUCEBM: '保姆注册',
  PRODUCTS_ZHUCEDB: '担保注册',
  patentEnable: true
}

const mutations = {
  SET_SETTING: (state, data) => {
    var personal_qq = data['basic']['personal_qq']
    var market = data['basic']['qq_link'] // 营销qq的链接
    var qqType = data['basic']['qq_type'] // 客服QQ类型
    var qqLink =
        qqType === 'personal'
          ? 'http://wpa.qq.com/msgrd?v=3&uin=' + personal_qq + '&site=qq&menu=yes'
          : market
    data['basic']['qq_link'] = qqLink
    state.setting = data
  },
  SET_TM_PRODUCT: (state, products) => {
    if (!products['faming'] && !products['shiyong'] && !products['waiguan'] && !products['zhuanlibohui']) {
      state.patentEnable = false
    }
    if (products && products['zhuce']) {
      state.PRODUCTS_ZHUCE = products['zhuce']['name']
    }
    if (products && products['zhucebm']) {
      state.PRODUCTS_ZHUCEBM = products['zhucebm']['name']
    }
    if (products && products['zhucedb']) {
      state.PRODUCTS_ZHUCEDB = products['zhucedb']['name']
    }
  },
  SET_CLASSIFY: (state, data) => {
    state.classData = data
  },
  SET_CLASSMAP: (state, data) => {
    state.classMap = data
  },
  SET_TOP_MENU: (state, data) => {
    state.topMenu = data
  }
}

const actions = {
  // 获取商标分类
  getClassify({ commit }) {
    return new Promise((resolve, reject) => {
      let url = ''
      if (process.env.NODE_ENV === 'development') {
        url = '/assets/tm-classes-alias.js'
      } else {
        url = './assets/tm-classes-alias.js'
      }
      require(url).then(alias => {
        const tmClass = alias
        const key = Object.keys(tmClass).sort()
        const arrayData = []
        // 处理数据格式
        // 临时转化为数组
        for (let index = 0; index < key.length; index++) {
          if (tmClass.hasOwnProperty(key[index])) {
            const obj = {
              id: key[index],
              name: tmClass[key[index]]
            }
            arrayData.push(obj)
          }
        }
        const temp = deepClone(tmClass)
        for (let index = 1; index < 10; index++) {
          temp[index] = temp['0' + index]
        }
        commit('SET_CLASSIFY', arrayData)
        commit('SET_CLASSMAP', temp)
      })
    })
  }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}

