/*
 * @Author: fengzg
 * @Date: 2020-01-14 15:35:08
 * @LastEditors: fengzg
 * @LastEditTime: 2020-10-27 18:04:08
 * @FilePath: \vue-center\src\store\modules\user.js
 * @Description: 会员登录 token
 * @WebSite: https://www.epower.cn/
 */

// 登录操作
import { getServerToken, removeServerToken, getInfo } from '@/api/modules/common'

// 获取token
import { getLocalToken, removeLocalToken } from '@/utils/storage'
import user from '@/router/modules/center'

const state = {
  Authorization: getLocalToken(),
  userInfo: {},
  userRouter: user
}

const mutations = {
  SET_TOKEN: (state, token) => {
    state.Authorization = token
  },
  SET_USER_INFO: (state, data) => {
    state.userInfo = data
  }
}

const actions = {
  // user login
  login({ commit }, userInfo) {
    return new Promise((resolve, reject) => {
      getServerToken(userInfo).then(res => {
        const { data } = res.data
        const token = data.token_type + ' ' + data.access_token
        // 保存token
        commit('SET_TOKEN', token)
        getInfo(token).then(res => {
          const { data } = res.data
          if (!data) {
            reject('验证失败，请重新登录')
            return
          }
          commit('SET_USER_INFO', data)
          resolve(data)
        }).catch(error => {
          this.dispatch('user/userLogout')
          reject(error)
        })
      }).catch(error => {
        reject(error)
      })
    })
  },
  userLogout({ commit }) {
    return new Promise((resolve, reject) => {
      removeServerToken().then(() => {
        commit('SET_TOKEN', '')
        commit('SET_USER_INFO', {})
        removeLocalToken()
        resolve()
      }).catch(error => {
        commit('SET_TOKEN', '')
        commit('SET_USER_INFO', {})
        removeLocalToken()
        reject(error)
      })
    })
  }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}

