
export function whetherShowCoupon(type) {
  if (!store.getters.setting.product) {
    return false
  }
  const coupon_enable = store.getters.setting.product.coupon_enable
  const coupon_products = store.getters.setting.product.coupon_products
  if (!coupon_enable) {
    return false
  }
  return coupon_products.indexOf(type) !== -1
}
/**
 * Parse the time to string
 * @param {(Object|string|number)} time
 * @param {string} cFormat
 * @returns {string}
 */
export function parseTime(time, cFormat) {
  if (arguments.length === 0) {
    return null
  }
  const format = cFormat || '{y}-{m}-{d} {h}:{i}:{s}'
  let date
  if (typeof time === 'object') {
    date = time
  } else {
    if ((typeof time === 'string') && (/^[0-9]+$/.test(time))) {
      time = parseInt(time)
    }
    if ((typeof time === 'number') && (time.toString().length === 10)) {
      time = time * 1000
    }
    date = new Date(time)
  }
  const formatObj = {
    y: date.getFullYear(),
    m: date.getMonth() + 1,
    d: date.getDate(),
    h: date.getHours(),
    i: date.getMinutes(),
    s: date.getSeconds(),
    a: date.getDay()
  }
  const time_str = format.replace(/{(y|m|d|h|i|s|a)+}/g, (result, key) => {
    let value = formatObj[key]
    // Note: getDay() returns 0 on Sunday
    if (key === 'a') { return ['日', '一', '二', '三', '四', '五', '六'][value ] }
    if (result.length > 0 && value < 10) {
      value = '0' + value
    }
    return value || 0
  })
  return time_str
}

/**
 * @param {number} time
 * @param {string} option
 * @returns {string}
 */
export function formatTime(time, option) {
  if (('' + time).length === 10) {
    time = parseInt(time) * 1000
  } else {
    time = +time
  }
  const d = new Date(time)
  const now = Date.now()

  const diff = (now - d) / 1000

  if (diff < 30) {
    return '刚刚'
  } else if (diff < 3600) {
    // less 1 hour
    return Math.ceil(diff / 60) + '分钟前'
  } else if (diff < 3600 * 24) {
    return Math.ceil(diff / 3600) + '小时前'
  } else if (diff < 3600 * 24 * 2) {
    return '1天前'
  }
  if (option) {
    return parseTime(time, option)
  } else {
    return (
      d.getMonth() +
      1 +
      '月' +
      d.getDate() +
      '日' +
      d.getHours() +
      '时' +
      d.getMinutes() +
      '分'
    )
  }
}

/**
 * @param {string} url
 * @returns {Object}
 */
export function param2Obj(url) {
  const search = url.split('?')[1]
  if (!search) {
    return {}
  }
  return JSON.parse(
    '{"' +
      decodeURIComponent(search)
        .replace(/"/g, '\\"')
        .replace(/&/g, '","')
        .replace(/=/g, '":"')
        .replace(/\+/g, ' ') +
      '"}'
  )
}

/**
 * This is just a simple version of deep copy
 * Has a lot of edge cases bug
 * If you want to use a perfect deep copy, use lodash's _.cloneDeep
 * @param {Object} source
 * @returns {Object}
 */
export function deepClone(source) {
  if (!source && typeof source !== 'object') {
    throw new Error('error arguments', 'deepClone')
  }
  const targetObj = source.constructor === Array ? [] : {}
  Object.keys(source).forEach(keys => {
    if (source[keys] && typeof source[keys] === 'object') {
      targetObj[keys] = deepClone(source[keys])
    } else {
      targetObj[keys] = source[keys]
    }
  })
  return targetObj
}

export function assignFrom(source, dest) {
  const targetObj = {}
  Object.keys(dest).forEach(key => {
    if (source.hasOwnProperty(key)) targetObj[key] = source[key]
    else targetObj[key] = dest[key]
  })
  return targetObj
}

/**
 * [getParam ]
 * @param  {String} name
 * @param  {String} url   [default:location.href]
 * @return {String|Boolean}
 */
export function getParam(name, url) {
  if (typeof name !== 'string') return false
  if (!url) url = window.location.href
  // 当遇到name[xx]时，对方括号做一下转义为 name\[xxx\]，因为下面还需要使用name做正则
  name = name.replace(/[\[\]]/g, '\\$&')
  var regex = new RegExp('[?&]' + name + '(=([^&#]*)|&|#|$)')
  var results = regex.exec(url)
  if (!results) return null
  if (!results[2]) return ''
  return decodeURIComponent(results[2].replace(/\+/g, ' '))
}

export function refreshPage(that) {
  if (!that || !that.$route) {
    return
  }
  const { fullPath } = that.$route
  that.$router.replace({
    path: '/redirect' + fullPath
  })
}
import store from '../store'

export function canSale(identity, isOr) {
  const product = store.getters.setting['product'] || {}
  product.saleable_products = product.saleable_products || []

  if (identity instanceof Array) {
    for (let i = 0; i < identity.length; i++) {
      if (isOr === false) {
        if (product.saleable_products.indexOf(identity[i]) < 0) return false
      } else {
        if (product.saleable_products.indexOf(identity[i]) >= 0) return true
      }
    }
    return isOr === false
  }
  return product.saleable_products.indexOf(identity) >= 0
}

export function debounceFunction(fn, timeout) {
  var timer = 0
  return function() {
    if (timer) window.clearTimeout(timer)
    var args = arguments; var that = this
    timer = window.setTimeout(function() {
      fn.apply(that, args)
    }, timeout)
  }
}

export default {
  install(Vue) {
    Vue.prototype.whetherShowCoupon = whetherShowCoupon
    Vue.prototype.deepClone = deepClone
    Vue.prototype.getParam = getParam
    Vue.prototype.refreshPage = refreshPage
  }
}
