/* eslint-disable */
import { IQuery } from "./iquery";
var cnames = {
  domainstatus: "status",
  roid: "domainid",
  sponsoringregistrar: "registrar",
  registrationtime: "creationdate",
  expirationtime: "expirationdate",
  registryexpirydate: "expirationdate",
  registrant: "registrantname",
  registrantcontactemail: "registrantemail"
};
var maps = {
  domainname: "域名",
  status: "状态",
  whoisserver: "WHOIS服务器",
  referralurl: "注册商网址",
  registrar: "注册商",
  nameserver: "DNS服务器",
  creationdate: "注册日期",
  expirationdate: "到期日期",
  updateddate: "更新日期",
  registrantid: "所有者ID",
  registrantname: "所有者",
  registrantemail: "所有者邮箱"
};

var monthes = {
  jan: "01",
  feb: "02",
  mar: "03",
  apr: "04",
  may: "05",
  jun: "06",
  jul: "07",
  aug: "08",
  sep: "09",
  sept: "09",
  oct: 10,
  nov: 11,
  dec: 12
};

// 日期格式化
function datetimeFilter(datetime) {
  if (!datetime) {
    return "";
  }
  var match = null;
  match = /^(\d+)\-([a-z]+)\-(\d+)$/i.exec(datetime);
  if (match) {
    return [match[3], monthes[match[2].toLowerCase()], match[1]].join("-");
  }
  match = /^(.+?)T(.+?)Z$/i.exec(datetime);
  if (match) {
    return match[1] + " " + match[2];
  }
  return datetime;
}

// /属性过滤，显示为中文
function attrFilter(name, eng) {
  name = name.replace(/\s/g, "").toLowerCase();
  if (eng === true) {
    return cnames[name] || name;
  }
  return maps[cnames[name] || name];
}

// /格式化WHOIS信息
export function formatWhois(whois, out, eng) {
  var result = IQuery(
    whois
      .replace(/\r\n/g, "\n")
      .replace(/\r/g, "\n")
      .replace(/\n\n/g, "\n")
      .split("\n")
  )
    .where(function(t) {
      return t != "" && t.indexOf(": ") > 0;
    })
    .select(function(t) {
      var index = t.indexOf(":");
      var name = t.substr(0, index).trim();
      var value = t.substr(index + 1).trim();
      name = attrFilter(name, true);
      if (name === undefined) return null;
      if (
        name == "creationdate" ||
        name == "expirationdate" ||
        name == "updateddate"
      ) {
        value = datetimeFilter(value);
      }
      return [name, value];
    })
    .where(function(t) {
      return t != null;
    })
    .toArray();
  var retValue = {};
  var k = 0;
  var item = null;
  var name;
  var value;
  var lists;

  for (var i = 0; i < result.length; i++) {
    item = result[i];
    name = item[0];
    value = item[1];
    if (!retValue.hasOwnProperty(name)) {
      retValue[name] = value;
    } else if (name == "nameserver" || name == "status") {
      lists = retValue[name];
      if (typeof lists === "string") {
        lists = [lists];
        retValue[name] = lists;
      }
      var find = false;
      if (name == "status") {
        value = value
          .replace(/[\)\(]/g, "")
          .replace("https://www.", "https://");
      }
      for (var j = 0; j < lists.length; j++) {
        if (lists[j].toLowerCase() == value.toLowerCase()) {
          find = true;
          break;
        }
      }
      if (find) {
        continue;
      }
      lists.push(value);
    }
  }
  return retValue;
}

// /清理几个后缀的WHOIS详情
function filterCOM(whois) {
  var index = whois.indexOf("Domain Name:");
  if (index < 0) {
    return whois;
  }
  whois = whois.substr(index);
  index = whois.indexOf("&gt;&gt;&gt");
  if (index <= 0) {
    return whois;
  }
  return whois.substr(0, index);
}
// /查询WHOIS
function getWhois(domain, content) {
  var _whois = content;
  var whois = _whois;
  var out = { detail: _whois, isCOM: false };
  var ext = domain.substr(domain.indexOf(".")).toLowerCase();
  if (
    ext == ".com" ||
    ext == ".net" ||
    ext == ".cc" ||
    ext == ".org" ||
    ext == ".tv"
  ) {
    whois = filterCOM(whois);
    out.isCOM = true;
    out.filterWhois = whois;
  }
  return formatWhois(whois, out);
}

// /查询WHOIS详情
function getWhoisDetail(domain, fn, error) {
  var options = {
    name: domain
  };
  utils.appendHash(options);
  utils.request(api_url + "whois?" + utils.encode2parms(options), function(
    err,
    res
  ) {
    if (err) {
      typeof error === "function" && error("查询失败:" + res.errMsg);
      return;
    }
    fn(res.data);
  });
}
