'use strict'
const path = require('path')
const webpack = require('webpack')
const port = process.env.port || process.env.npm_config_port || 9999 // dev port
function resolve(dir) {
  return path.join(__dirname, dir)
}

function merge(a, b) {
  if (a && b) {
    for (var key in b) {
      if (!b.hasOwnProperty(key)) continue
      a[key] = b[key]
    }
  }
  return a
}
function createProxy(matches, target) {
  const proxies = {}
  for (let i = 0; i < matches.length; i++) {
    proxies[matches[i]] = target
  }
  return proxies
}
const name = '用户中心'
module.exports = {
  publicPath: '/',
  outputDir: 'dist',
  assetsDir: 'statics/user',
  lintOnSave: process.env.NODE_ENV !== 'production',
  productionSourceMap: false,
  filenameHashing: false,
  devServer: {
    port: port,
    host: '0.0.0.0',
    open: false,
    overlay: {
      warnings: false,
      errors: true
    },
    proxy: createProxy(['/v1', '/statics/epower', '/statics/themes', '/assets', '/upload', '/Uploads', '/platform_variables'], {
      target: process.env.VUE_APP_BASE_TARGET || 'http://v1.user.epower.cn',
      changeOrigin: true
    })
  },

  configureWebpack: config => {
    return {
      plugins: [
        new webpack.ProvidePlugin({
          $: 'jquery',
          jQuery: 'jquery',
          'windows.jQuery': 'jquery'
        })
      ],
      name: name,
      resolve: {
        alias: {
          '@': resolve('src')
        }
      }
    }
  },
  chainWebpack(config) {
    if (process.env.NODE_ENV !== 'development') {
      config.output.filename('statics/user/js/[name].js?[hash:8]').end()
      config.output.chunkFilename('statics/user/js/[name].js?[chunkhash:8]').end()
      config.plugin('extract-css').tap(args => [{
        filename: `statics/user/css/[name].css?[hash:8]`,
        chunkFilename: `statics/user/css/[name].css?[chunkhash:8]`
      }])
    }
    config.plugin('html').tap(args => {
      args[0].minify = false
      return args
    })
    config.plugins.delete('preload') // TODO: need test
    config.plugins.delete('prefetch') // TODO: need test

    

    config.module
      .rule('images')
      .use('url-loader')
      .tap(options =>
        merge(options, {
          limit: '1024'
        }))

    config.module
      .rule('vue')
      .use('vue-loader')
      .loader('vue-loader')
      .tap(options => {
        options.compilerOptions.preserveWhitespace = false
        return options
      })
      .end()

    

    config.when(process.env.NODE_ENV === 'development',
      config => config.devtool('cheap-source-map')
    )

    config.when(process.env.NODE_ENV !== 'development', config => {
      config.plugin('ScriptExtHtmlWebpackPlugin')
        .after('html')
        .use('script-ext-html-webpack-plugin', [{
          inline: /runtime\..*\.js$/
        }])
        .end()
      config.optimization.splitChunks({
        chunks: 'all',
        cacheGroups: {
          libs: {
            name: 'vendors',
            test: /[\\/]node_modules[\\/]/,
            priority: 10,
            chunks: 'initial'
          },
          elementUI: {
            name: 'chunk-element-ui',
            priority: 20,
            test: /([\\/]node_modules[\\/]_?element-ui(.*))|(src[\\/]assets[\\/]element-ui)/
          },
          commons: {
            name: 'commons',
            test: resolve('src/components'),
            minChunks: 3,
            priority: 5,
            reuseExistingChunk: true
          }
        }
      })
      config.optimization.runtimeChunk('single')
    })
  }
}
